import { InputLabel, MenuItem, Select } from '@mui/material';
import dynamic from 'next/dynamic'
import React, { useState } from 'react'
import InputField from './InputField';
import SpotParking from './SpotParking';
import { useSelector, useDispatch } from 'react-redux';
import { uploadImage } from '@/store/userReducer';
import Loader from '@/pages/Loader';
import { addNewParkingsSpot } from '@/store/userSlice';
import { useTranslation } from 'react-i18next';
import i18n from '../../i18n';


const FontIcon = dynamic(() => import('./FontIcon'), { ssr: false })


function EditParkingLots({ setEditParking }) {
    const { t } = useTranslation()
    const { allAdmins, adminData, loader, parkingsSpots, smsSendTime } = useSelector(state => state.user)
    const dispatch = useDispatch()


    const [checkField, setCheckField] = useState(false)
    const [parkinglotDetail, setparkinglotDetail] = useState({
        name: '',
        designated: 0,
        accessMapFile: null,
        regular: 0,
        maxReservationDistance: '',
        admins: [],
        allotmentFile: null,
        electric: 0,
        allotmentMethod: 'user-selected',
        electricChargingTimeLimit: '',
        parkingLotImageFile: null,
        location: {
            name: "",
            latitude: '',
            longitude: ''
        },
        avatar: null,
        chargingTimeLimit: false,
        chargingTimeStart: "",
        chargingTimeEnd: "",
        smsSendTime: '',
        reservationTime: '',
        messageSendTime: '',
        messageSendTimeOfDay: '',
        designatedReservationDuration: ''
    });

    const adminOptions = allAdmins?.admins?.map(admin => ({ label: admin.firstName, value: admin._id }))?.concat({
        label: adminData?.admin?.firstName,
        value: adminData?.admin?._id
    });;

    const times = Array.from({ length: 24 / 2 }, (_, index) => {
        const startHour = (index * 2).toString().padStart(2, '0');
        const endHour = ((index * 2) + 2).toString().padStart(2, '0');
        return `${startHour}:00-${endHour}:00`;
    });

    // [
    //     { label: t('time18'), value: '18:00 evening-before' },
    //     { label: t('time8'), value: '08:00 morning' },
    // ],

    const formConfig = [
        { key: 'name', label: 'Name', type: 'text' },
        { key: 'location', label: 'Address', type: 'text' },
        { key: 'smsSendTime', label: 'SMS Send Time', type: 'time' },
        { key: 'accessMapFile', label: 'Access Map File', type: 'file' },
        { key: 'designatedReservationDuration', label: 'designated reservation duration', type: 'text', },
        { key: 'maxReservationDistance', label: 'Maximum Reservation Distance', type: 'text', required: false },
        { key: 'admins', label: 'Parking Lot Admin/s', type: 'select', options: adminOptions, },
        { key: 'avatar', label: 'Parking Lot Image File', type: 'file', },
        { key: 'reservationTime', label: 'Reservation Time', type: 'select', options: [{ label: t('DayBefore'), value: 'day-before' }, { label: t('SameDay'), value: 'same-day' }], },

        // { key: 'allotmentMethod', label: 'Allotment Method', type: 'select', options: ['user-selected'], },
        // { key: 'electricChargingTimeLimit', label: 'Electric Charging Time Limit', type: 'select', options: times, },
        // { key: 'smsSendTime', label: 'SMS Send Time', type: 'select', options: smsSendTime },
        // { key: 'daybefore', label: 'Day For Reservation Time', type: 'select', options:['today','tomorrow'] },
        // { key: 'empty', label: 'Name', type: 'text' },
        // { key: 'allotmentFile', label: 'Allotment File', type: 'file' },
        // { key: 'electric', label: 'Electric Charging Station', type: 'text', required: false },
        // { key: 'regular', label: 'Regular Parking Spots', type: 'text', required: false },
        // { key: 'designated', label: 'Designated Parking Spots', type: 'text', required: false },
    ];

    const handleChange = (e, key, type) => {
        const { value } = e.target;
        setparkinglotDetail((prevDetails) => {
            let updatedDetails = { ...prevDetails };
            if (key === 'electricChargingTimeLimit') {
                updatedDetails = {
                    ...updatedDetails,
                    chargingTimeLimit: value !== '',
                    chargingTimeStart: value !== '' ? value.split('-')[0] : '',
                    chargingTimeEnd: value !== '' ? value.split('-')[1] : '',
                    [key]: value,
                };
            } else if (key == 'smsSendTime') {
                updatedDetails = {
                    ...updatedDetails,
                    messageSendTime: value !== '' ? value.split(' ')[0] : '',
                    messageSendTimeOfDay: value.split(' ')[1] ? value.split(' ')[1] : '',
                    [key]: value
                }

            } else {
                updatedDetails[key] = type == 'file' ? e.target.files[0] : key == 'location' ? { ...parkinglotDetail?.location, name: e.target.value } : e.target.value
            }
            return updatedDetails;
        });
    };

    const isValidParkingLot = () => {
        const {
            name,
            accessMapFile,
            admins,
            allotmentMethod,
            location,
            avatar,
            smsSendTime,
            reservationTime,
            designatedReservationDuration,
            // maxReservationDistance
        } = parkinglotDetail;

        if (name == '' || accessMapFile == null || location.name == '' || admins.length == 0 || allotmentMethod == '' || avatar == null || smsSendTime == '' || reservationTime == '' || designatedReservationDuration == '') {
            return false
        }

        const durationPattern = /^(?:[01]\d|2[0-3]):(?:[0-5]\d)$/;
        if (!durationPattern.test(designatedReservationDuration)) {
            alert('Please Check Format of Designated Reservation Duration\nFor Example: hh:mm (i.e, 01:35)')
            return false;
        }

        return true;
    };

    const handleSubmit = (e) => {
        e.preventDefault();
        if (isValidParkingLot()) {
            dispatch(uploadImage({ data: parkinglotDetail, token: adminData?.token }))
            setEditParking()
            setparkinglotDetail({
                name: '',
                designated: 0,
                accessMapFile: null,
                regular: 0,
                maxReservationDistance: '',
                admins: [],
                allotmentFile: null,
                electric: 0,
                allotmentMethod: '',
                electricChargingTimeLimit: '',
                parkingLotImageFile: null,
                location: {
                    name: "",
                    latitude: '',
                    longitude: ''
                },
                avatar: null,
                chargingTimeLimit: false,
                chargingTimeStart: "",
                chargingTimeEnd: "",
                smsSendTime: '',
                reservationTime: '',
                designatedreservationduration: ''
            })
            // console.log('Form submitted:', parkinglotDetail);
        } else {
            setCheckField(true)
        }
    };



    return (
        <div className='h-[90%] overflow-y-auto w-full'>
            {loader && <Loader />}
            <div className='shadow-lg rounded-[15px] mt-3  mx-5 overflow-x-auto '>
                {/* <FontIcon size='xl' iconname={`fa-solid fa-trash-can `} className={`text-appLightGrey rounded-full ml-5 mt-5 hover:cursor-pointer hover:text-appSeaGreen 'hover:shadow-md`} /> */}
                <form onSubmit={handleSubmit} className='flex flex-col  items-center pt-2 mx-10 justify-center   '>
                    <div className='flex flex-wrap gap-3 w-full items-center '>
                        {formConfig.map((config) => (
                            <div className={`flex flex-col ${config.type == 'file' ? 'w-[14%]' : 'w-[25%]'} ${config.key == 'empty' && 'invisible'}  self-start`} key={config.key}>
                                <label className={`font-normal text-[15] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'}  text-appBlack`} htmlFor={config.key}>{t(config.key)}</label>
                                {config.type === 'select' ? (
                                    <Select
                                        required={false}
                                        id={config.key}
                                        name={config.key}
                                        value={parkinglotDetail[config.key]}
                                        onChange={(e) => handleChange(e, config.key)}
                                        className="mt-1  w-full rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                                        displayEmpty
                                        multiple={config.key == 'admins' ? true : false}
                                    >
                                        <MenuItem value="" disabled>
                                            {config.key == 'electricChargingTimeLimit' ? t('nolimit') : t('adminSelectoption')}
                                        </MenuItem>
                                        {config?.options?.map((option) => {
                                            return <MenuItem key={config.key === 'admins' || config.key == 'smsSendTime' || config.key == 'reservationTime' ? option?.value : option} value={config.key === 'admins' || config.key == 'smsSendTime' || config.key == 'reservationTime' ? option?.value : option}>
                                                {config.key === 'admins' || config.key == 'smsSendTime' || config.key == 'reservationTime' ? (i18n.language == 'he' && option?.labelHeb) ? option?.labelHeb : option?.label : (config.key === 'allotmentMethod' || config.key === 'smsSendTime' || config.key === 'reservationTime') ? t(option) : option}
                                            </MenuItem>

                                        })}
                                    </Select>
                                )
                                    : (
                                        <InputField
                                            setparkinglotDetail={setparkinglotDetail}
                                            parkinglotDetail={parkinglotDetail}
                                            disabled={config.key == 'designated' || config.key == 'regular' || config.key == 'electric' && true}
                                            required={false}
                                            type={config.type}
                                            id={config.key}
                                            name={config.key}
                                            value={config.key == 'location' ? parkinglotDetail[config.key].name : parkinglotDetail[config.key]}
                                            onChange={(e) => handleChange(e, config.key, config.type)}
                                        />
                                    )
                                }
                                {config.key == 'designatedReservationDuration' && <p className={`text-appGreyLight42 ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik '} font-normal text-[11px] pt-1 `}>{t('timeformat')}</p>}
                                {checkField && (config.key != 'electricChargingTimeLimit' && config.key != 'allotmentFile') && <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik '} font-normal ${config.key == 'empty' && 'invisible'} text-[11px] pt-1 ${((parkinglotDetail[config.key] == '' || parkinglotDetail[config.key] == null) && config.required != false) || parkinglotDetail[config.key].name == '' ? 'visible' : 'invisible'}`}>{(config.type == 'file') ? t('uploadfillalert') : t('fillalert')}</p>}
                                {checkField && (config.key == 'allotmentFile' && parkinglotDetail.allotmentMethod == 'manual') && <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik '} ${config.key == 'empty' && 'invisible'} font-normal text-[11px] pt-1`}>{t('uploadfillalert')}</p>}
                            </div>
                        ))}
                    </div>
                    <div className='flex pb-6 mt-4 items-center justify-center'>
                        <button
                            type='submit'
                            className={`bg-transparent transition-all delay-100 hover:bg-appSeaGreen hover:text-appWhite w-[108px] h-[40px] text-appSeaGreen border-2 border-appSeaGreen  rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-bold font-spartan' : 'font-rubik font-medium'}  cursor-pointer `}
                        >
                            {t('save')}
                        </button>
                    </div>
                </form>

            </div>


        </div>
    )
}

export default EditParkingLots