import React from 'react'
import { useTranslation } from 'react-i18next'
import i18n from '../../i18n'
import Link from 'next/link'
import Image from 'next/image'
import { svgImages } from '@/utilities/utils'
import { useSelector } from 'react-redux'

const GuestUser = ({ guestUser }) => {
    const { t } = useTranslation()
    return (
        <div className='h-[74vh]'>
            {guestUser == null && <p className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-2xl'} font-normal py-5`}>
                {t('guestinfotext')}
            </p>}
            {guestUser?.length == 0 && <div className='bg-appNewYellowLight rounded-md flex items-center justify-center my-7'>
                <p className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-2xl'} font-normal py-5`}>
                    {t('guestnouserfound')}
                </p>
            </div>}

            {guestUser?.length > 0 &&
                <div >
                    {guestUser?.map((guest, index) => {
                        return (
                            <div key={index} className='flex items-center justify-between border-b border-appSeaGreen mx-3 px-2'>
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-xl'} font-normal  `}>{guest?.firstName}</p>
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-xl'} font-normal `}>{t('guestusercarnumber')} {guest?.vehicles?.[0]?.registration}</p>
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-xl'} font-normal `}>{t('guestuserphonenumber')} {guest?.phoneNumber?.number}</p>
                                <div className='flex items-center justify-center'>
                                    <p className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-xl'} font-normal `}>{t('guestuseraccounstatus')} </p>
                                    <div className='flex items-center justify-center mx-1 gap-1'>
                                        {guest?.failedLoginAttempts < 3 ? <div className='w-3 h-3 rounded-md bg-appParrotGreen' /> : <Image alt='locked icon' className='h-5 w-5' src={svgImages.lockedUp} />}
                                        <p className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-xl'} font-normal `}>{guest?.failedLoginAttempts < 3 ? t('newDesignActive') : t('newDesignInactive')}</p>
                                    </div>
                                </div>
                                <Link href={`/editUser?data=${JSON.stringify(guest)}`} as="/editUser" className='overflow-scroll py-3 flex items-center justify-center px-24 bg-appnewdarkgreen my-2 rounded-[50px]'>
                                    <p className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-[22px]'} font-medium text-appWhite `}>{t('guestusersearchbtn')}</p>
                                </Link>
                            </div>
                        )
                    })}
                    <p className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-2xl'} font-normal py-5 px-8`}>
                        {t('guestinfobtn')}
                    </p>
                </div>
            }

        </div>
    )
}

export default GuestUser