import { useEffect, useRef, useState } from 'react';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import i18n from '../../i18n';
import { useTranslation } from 'react-i18next';
import { useDispatch, useSelector } from 'react-redux';
import Image from 'next/image';
import { IMAGES, svgImages } from '@/utilities/utils';
import moment from 'moment';
import FontIcon from './FontIcon';
import Modal from './model';
import Link from 'next/link';
import SortableHeader from './Layout/SortableHeader';




function OccupancyList({sortType, tableHeader,handleGuestUserDelete, Details, height, sorting, guest = false }) {
    const { t } = useTranslation()
    const { loader , adminData } = useSelector(state => state.user)
    const tableHeaderRef = useRef(null);
    const [marginTop, setMarginTop] = useState(tableHeaderRef.current?.clientHeight && tableHeaderRef.current.clientHeight)
    const [activeSorting, setActiveSorting] = useState(null)
    const [showDeleteModal,setShowDeleteModal] = useState(false) 
    const dispatch = useDispatch()
    const [deleteUserId, setDeleteUserId] = useState(null)

    useEffect(() => {
        const headerHeight = tableHeaderRef.current.clientHeight;
        setMarginTop(headerHeight)
    }, [i18n.language, tableHeaderRef, Details,guest])

    useEffect(() => {
        const handleResize = () => {
            if (tableHeaderRef.current) {
                const headerHeight = tableHeaderRef.current.clientHeight;
                setMarginTop(headerHeight)
            }
        };

        window.addEventListener('resize', handleResize);

        return () => {
            window.removeEventListener('resize', handleResize);
        };
    }, []);

    //event handlers
    const closeModal = ()=>setShowDeleteModal(false)

    const slotImage = (status, type, isFrozen) => {
        if (isFrozen) {
            return { style: "bg-appDarkGrey rounded-sm text-appWhite" }
        }

        if (status == 'reserved') {
            return { style: "border-2 border-appNewRed" }
        } else if (status == 'designated-not-released') {
            return { style: "bg-appNewRed" }
        } else {
            return { style: "border-2 border-appNewGreen" }
        }

    }

    const handleDeleteGuest=()=>{
        if(!deleteUserId) return
        handleGuestUserDelete(deleteUserId)
        setShowDeleteModal(false)
    }


    return (
        <>
        <TableContainer sx={{
            boxShadow: 'none',
            maxHeight: height,
            '&::-webkit-scrollbar': {
                width: '6px',
                backgroundColor: 'transparent',
            },
            '&::-webkit-scrollbar-thumb': {
                backgroundColor: '#737373',
                borderRadius: '3px',
            },
            '&::-webkit-scrollbar-track': {
                backgroundColor: 'transparent',
                marginTop: `${marginTop}px`
            },
        }} component={Paper}>
            <Table sx={{
                minWidth: 650,
                '& th, & td': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000',
                    fontSize: '14px',
                    fontWeight: 300,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif'
                },
                '& th': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000000',
                    fontSize: '15px',
                    fontWeight: i18n.language == 'en' ? 700 : 500,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif',
                },
            }}
                stickyHeader aria-label="simple table">
                <TableHead >
                    <TableRow ref={tableHeaderRef}>
                        {
                            tableHeader.map((head, index) => {
                                return (
                                  <SortableHeader
                                    key={`${head.id}-${index}`}
                                    head={head}
                                    index={index}
                                    activeSorting={activeSorting}
                                    sortType={sortType}
                                    sorting={sorting}
                                    classes={
                                      guest
                                        ? ""
                                        : index === 0 || index === 1
                                        ? "justify-center"
                                        : "justify-start"
                                    }
                                    setActiveSorting={setActiveSorting}
                                  />
                                );
                            })
                        }
                    </TableRow>
                        </TableHead>
                <TableBody>
                    {Details?.map((spot,index) => {
                        return (
                            <TableRow
                                key={index}
                                sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
                            >
                                <TableCell style={{ verticalAlign: 'top' }} align={ guest ? i18n.language == 'en'? "left": "right":"center"}>{guest ? (spot?.firstName ? spot?.firstName : '-') : (spot?.level?.name ? spot?.level?.name : '-')}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align={ guest ? i18n.language == 'en'? "left": "right":"center"}>{guest ? (spot?.phoneNumber?.number ? spot?.phoneNumber?.number : '-') : (spot?.parkingCode ? spot?.parkingCode : '-')}</TableCell>
                                <TableCell style={{ verticalAlign: 'top', width: i18n.language == 'en' && '20%' }} align={`${i18n.language == 'en'? "left" : "right"}`}> {guest ? (spot?.vehicles?.length > 0 ? spot?.vehicles?.map((vehicle, index) => {
                                    return (
                                        <div key={index}>
                                            <p>{vehicle?.registration}</p>
                                            <br />
                                        </div>
                                    )
                                }) : '-') : <div ><p className={`${slotImage(spot?.status, spot?.spotType, spot?.isPermanent).style} inline px-2`}>{(spot?.isPermanent || spot?.status) ? spot?.isPermanent ? t('locked') : t(spot?.status) : '-'}</p></div>}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language == 'en'? "left" : "right"}`}>{guest ? (spot?.disabled ? <div className='flex items-center justify-start gap-1'>
                                    <p>{t('UserTableYes')}</p>
                                    <Image alt='disabledIcon' className='w-5 h-5' src={svgImages.disableNewUserTable} />
                                </div> : t('UserTableNo')) : (spot?.spotType ? t(spot?.spotType) : '-')}</TableCell>
                                {guest && <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{spot?.electricCharging  ? <div className='flex items-center justify-start'>
                                    <Image alt='electric icon' height={24} width={24} src={svgImages.electricNewUserTable} />
                                </div> : ''}</TableCell> }
                                <TableCell style={{ verticalAlign: 'top' }}align={`${i18n.language == 'en'? "left" : "right"}`}>{guest ? (spot?.designatedParkingSpot?.length > 0 ? spot?.designatedParkingSpot?.map((designatedSpot, index) => {
                                    return (
                                        <div key={index}>
                                            <p>{designatedSpot?.parkingCode}</p>
                                            <br />
                                        </div>
                                    )
                                }) : '-') : (spot?.designatedTo?.firstName ? spot?.designatedTo?.firstName : '-')}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language == 'en'? "left" : "right"}`}>{guest ? (spot?.createdAt ? moment(spot?.createdAt).format('DD/MM/YY') : '-') : (spot?.reservedBy?.firstName ? spot?.reservedBy?.firstName : '-')} </TableCell>
                                {!guest && <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language == 'en'? "left" : "right"}`}>{spot?.reservedBy || spot?.designatedTo ? spot?.reservedBy?.phoneNumber?.number || spot?.designatedTo?.phoneNumber?.number : '-'} </TableCell>}
                                {!guest && <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language == 'en'? "left" : "right"}`}>{spot?.reservedBy || spot?.designatedTo ? spot?.reservedBy?.vehicles?.[0]?.registration || spot?.designatedTo?.vehicles?.[0]?.registration : '-'} </TableCell>}
                                {guest ? (
                                    <TableCell style={{ verticalAlign: 'top' }}>
                                    <Link href={`/editUser?data=${JSON.stringify({...spot,disableEdit:false})}`} as="/editUser" >
                                        <FontIcon iconname="fa-solid fa-pen" size="sm" className='text-appLightGrey mt-0 invert hover:filter-invert-sepia-saturate-hue hover:cursor-pointer' />
                                    </Link>
                                </TableCell>
                                ) : null}
                                {guest ? ( <TableCell style={{ verticalAlign: 'top' }}>
                                    <FontIcon handleClick={() => {setShowDeleteModal(true);setDeleteUserId(spot?._id)}} iconname="fa-solid fa-trash-can" size="sm" className='text-appLightGrey mt-0 invert hover:filter-invert-sepia-saturate-hue hover:cursor-pointer' />
                                </TableCell>):null}
                            </TableRow>

                        )
                    }

                    )}
                </TableBody>
            </Table>
        </TableContainer>
        <Modal isOpen={showDeleteModal} onClose={closeModal} >
                    <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
                        <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
                    </div>
                    <Image onClick={closeModal} className={`mt-5 mx-3 ${i18n.language == 'he' && 'rotate-180 '} hover:cursor-pointer`} alt='backbtn' src={svgImages.modalbackbtn} />

                    <div className='w-[450px]'>
                        <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-center text-[18px] mt-4 px-0`}>
                            {t('deleteUserModalText')}
                        </p>
                    </div>
                    <div className='flex  mt-8 items-center justify-center'>
                        <button
                            onClick={() => handleDeleteGuest()}
                            className='bg-transparent mb-7 w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] font-bold font-spartan cursor-pointer '
                        >
                            {t('accept')}
                        </button>
                    </div>
                </Modal>
        </>
    )
}

export default OccupancyList