import dynamic from 'next/dynamic'
import React from 'react'
import i18n from '../../i18n'
import { useTranslation } from 'react-i18next'
import { svgImages } from '@/utilities/utils'
import Image from 'next/image'


const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })

const Single_MultipleSelectDropdown = ({ dropdownOpen, setDropdownOpen, parkingLots, selectedParkingLot, setSelectedParkingLot, dropDownType = 'singleSelect' }) => {
    const { t } = useTranslation()
    const parkingLotsCheck = dropDownType == 'singleSelect' ? parkingLots : [{ name: t('associatesdropdownallparkinglots') }, ...parkingLots]

    const handleChange = (item, index) => {
        if (dropDownType == 'singleSelect') {
            setSelectedParkingLot(item)
            setDropdownOpen(false)
        } else {
            if (index == 0) {
                if (selectedParkingLot?.length == parkingLots?.length) {
                    setSelectedParkingLot([])
                } else {
                    setSelectedParkingLot(parkingLots)
                }
            } else {
                if (selectedParkingLot?.find(lot => lot?._id == item?._id)) {
                    const filterParkingLots = selectedParkingLot?.filter(lot => lot?._id != item?._id)
                    setSelectedParkingLot(filterParkingLots)
                } else {
                    setSelectedParkingLot([...selectedParkingLot, item])
                }
            }
        }
    }
    return (
        <>
            <div onClick={() => setDropdownOpen()} className='w-full h-full rounded-[28px]  flex items-center justify-between px-6 select-none overflow-hidden'>
                <h1 className={`${i18n.language == 'en' ? 'font-spartan text-base' : 'font-rubik text-xl'} font-normal`}>{selectedParkingLot?.name ? selectedParkingLot?.name : t('newDesignUserDropdownText')}</h1>
                <FontIcon size='xs' iconname="fa-solid fa-chevron-down" className='text-appLightGrey rounded-full invert  ' />
            </div>
            <div className={`z-10 ${dropdownOpen ? 'max-h-[298px] duration-200' : 'max-h-0 duration-150 invisible'} overflow-scroll bg-appWhite shadow-[0px_4px_30px_0px_#00000015] w-full absolute top-[59px] rounded-2xl py-2`}>
                {
                    parkingLotsCheck?.map((item, index) => {
                        return (
                            <div onClick={() => { handleChange(item, index) }} key={index} className={`flex select-none items-center cursor-pointer ${parkingLotsCheck?.length - 1 == index ? 'border-0' : 'border-b'} ${i18n.language == 'en' ? `${selectedParkingLot?._id == item?._id ? 'border-l-2' : ''} ${dropDownType == 'singleSelect' && 'hover:border-l-2'}` : `${dropDownType == 'singleSelect' && selectedParkingLot?._id == item?._id ? 'border-r-2' : ''} ${dropDownType == 'singleSelect' && 'hover:border-r-2'}`} border-appnewdarkgreen  mx-3`}>
                                {(dropDownType != 'singleSelect' && index != 0) ?
                                    (selectedParkingLot?.find(lot => lot?._id == item?._id) ?
                                        <Image alt='icon' className='w-5 h-5' src={svgImages.dropdowncheckbox} /> :
                                        <Image alt='icon' className='w-5 h-5' src={svgImages.dropdownuncheckedcheckbox} />) :
                                    (dropDownType != 'singleSelect' && index == 0 && selectedParkingLot?.length == parkingLots?.length) ?
                                        <Image alt='icon' className='w-5 h-5' src={svgImages.dropdowncheckbox} /> :
                                        (dropDownType != 'singleSelect' && index == 0 && selectedParkingLot?.length == 0) ?
                                            <Image alt='icon' className='w-5 h-5' src={svgImages.dropdownuncheckedcheckbox} /> :
                                            (dropDownType != 'singleSelect' && index == 0 && selectedParkingLot?.length > 0 && selectedParkingLot?.length < parkingLots?.length) &&
                                            <Image alt='icon' className='w-5 h-5' src={svgImages.dropdonwminuscheckbox} />
                                }
                                <p className='px-5 py-[6px]'>{item?.name}</p>
                            </div>
                        )
                    })
                }
            </div>
        </>
    )
}

export default Single_MultipleSelectDropdown