import React from 'react'
import Image from 'next/image';
import { IMAGES, svgImages } from '@/utilities/utils';
import i18n from '../../i18n';
import { useTranslation } from 'react-i18next';


const SlotStatusInfo = ({ setFullScreen }) => {
    const { t } = useTranslation()
    const slotStatusInfo = [
        {
            name: 'freeInfo',
            icon: IMAGES.empty
        },
        {
            name: 'reservedInfo',
            icon: IMAGES.reserved
        },
        {
            name: 'inUse',
            icon: IMAGES.inuse
        },
        {
            name: 'accessible',
            icon: IMAGES.accessible
        },
        {
            name: 'locked',
            icon: IMAGES.locked
        },
    ]
    return (
        <div className='flex items-center gap-3'>
            <div className='flex flex-col items-center gap-[2px]'>
                <p className={`${i18n.language == 'en' ? 'font-spartan text-[12px]' : 'font-rubik'} text-white font-normal text-[15px]`}>{t('legend')}</p>
                <Image className={`${i18n.language == 'en' && 'rotate-180'}`} alt='arrow' height={16} width={16} src={svgImages.bluearrow} />
            </div>

            {
                slotStatusInfo?.map((status, index) => {
                    return (
                        <div className='flex items-center ' key={index}>
                            <div className='flex items-center gap-1'>
                                <Image alt='icons' src={status?.icon} />
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-[12px]' : 'font-rubik'} font-normal text-[15px] text-appWhite`}>{t(status.name)}</p>
                            </div>
                            {index == 2 && <div className={`${i18n.language == 'en'?'ml-3':'mr-3'} w-[1px] h-[24px] bg-appgrey99`} />}
                        </div>
                    )
                })
            }

            <Image onClick={() => setFullScreen()} alt='fullscreenicon' width={32} height={32} src={svgImages.Fullscreen} />

        </div>
    )
}

export default SlotStatusInfo