import React from 'react'
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import dynamic from 'next/dynamic';
import { useRouter } from 'next/router';
import Link from 'next/link';
import InputFile from './InputFile';
import { TextField } from '@mui/material';
import { useSelector, useDispatch } from 'react-redux';
import { deleteParkingsSpot, updateParkingsSpots } from '@/store/userSlice';





const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })


function SpotParking({ tableHeader, Details , handleInputChange}) {
    const router = useRouter()
    const dispatch = useDispatch()
    const handleDeleteSpot = (index) => {
        // dispatch(deleteParkingsSpot(index))
    }
    return (
        <TableContainer sx={{
            boxShadow: 'none',
            maxHeight: '37vh',
        }} component={Paper}>
            <Table sx={{
                minWidth: 650,
                borderCollapse: 'collapse',
                '& th, & td': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000',
                    fontSize: '14px',
                    fontWeight: 300
                },
                '& th': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000000',
                    fontSize: '15px',
                    fontWeight: 'bold',
                },
            }}
                aria-label="simple table">
                <TableHead >
                    <TableRow>
                        {
                            tableHeader.map((head, index) => {
                                return (
                                    <TableCell className='font-spartan font-bold ' key={index} align='center'>{head?.title}</TableCell>
                                )
                            })
                        }
                    </TableRow>
                </TableHead>
                <TableBody>
                    {Details.map((user, index) => (
                        <TableRow
                            key={index}
                            sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
                        >
                            <TableCell align="center" scope="row">
                                <TextField
                                    value={user?.level}
                                    onChange={(e) => handleInputChange(e, index, 'areaName')} // Implement a function to handle input changes
                                    variant="outlined"
                                    size="small"
                                    fullWidth
                                />
                            </TableCell>
                            <TableCell align="center">
                                <TextField
                                    value={user?.regularParkingSpots}
                                    onChange={(e) => handleInputChange(e, index, 'regularParkingSpots')}
                                    variant="outlined"
                                    size="small"
                                    fullWidth
                                />
                            </TableCell>
                            <TableCell align="center">
                                <TextField
                                    value={user?.electricChargingParkingSpots}
                                    onChange={(e) => handleInputChange(e, index, 'electricChargingParkingSpots')}
                                    variant="outlined"
                                    size="small"
                                    fullWidth
                                />
                            </TableCell>
                            <TableCell align="center">
                                <TextField
                                    value={user?.designatedParkingspots}
                                    onChange={(e) => handleInputChange(e, index, 'designatedParkingspots')}
                                    variant="outlined"
                                    size="small"
                                    fullWidth
                                />
                            </TableCell>
                            <TableCell align="center">
                                <TextField
                                    value={user?.entrance}
                                    onChange={(e) => handleInputChange(e, index, 'entrance')}
                                    variant="outlined"
                                    size="small"
                                    fullWidth
                                />
                            </TableCell>
                            <TableCell>
                                <div className='min-w-[80px] self-start'>
                                    <InputFile name={user?.mapFile} value={user?.mapFile} onChange={(e) => handleInputChange(e, index, 'mapFile')} />
                                </div>
                            </TableCell>
                            <TableCell>
                                <FontIcon handleClick={() => handleDeleteSpot(index)} iconname="fa-solid fa-trash-can" size="sm" className='text-appLightGrey mt-0 hover:text-appSeaGreen hover:cursor-pointer' />
                            </TableCell>
                        </TableRow>
                    ))}
                </TableBody>
            </Table>
        </TableContainer>
    )
}

export default SpotParking