import React, { memo, useEffect, useMemo, useRef, useState } from 'react'
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import dynamic from 'next/dynamic';
import { useRouter } from 'next/router';
import InputFile from './InputFile';
import { TextField } from '@mui/material';
import { useSelector, useDispatch } from 'react-redux';
import { deleteLevel, updateLevel, uploadImage2, uploadVideo } from '@/store/userReducer';
import i18n from '../../i18n';





const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })

function SpotParking({ tableHeader, Details, handleInputChange, isNewRow, setNewRow, parkingLot }) {
    const { adminData } = useSelector(state => state.user)
    const router = useRouter()
    const dispatch = useDispatch()
    const [editableSpot, setEditableSpot] = useState(null)

    // console.log('level ==', Details)

    const levelNameRef = useRef();
    const regularRef = useRef();
    const electricRef = useRef();
    const designatedRef = useRef();
    const entranceRef = useRef();
    const disabledParkingSpotsRef = useRef()
    const doubleParkingSpotsRef = useRef()
    const frozenSpotRef = useRef()

    const [map, setMap] = useState(null)

    const [updatedMap, setUpdatedMap] = useState(null)

    const isValidForm = () => {
        if (levelNameRef.current == null || designatedRef.current == null ||
            entranceRef.current == null || map == null) {
            return false
        }
        if (levelNameRef.current == '' || designatedRef.current == '' ||
            entranceRef.current == '' || map == null) {
            return false
        }
        return true
    }


    const handleSaveSpot = () => {
        // let payload = {
        //     name: levelNameRef.current, regular: regularRef.current, electric: electricRef.current,
        //     designated: designatedRef.current, entrance: entranceRef.current, map, parkingLotId: parkingLot?._id,
        //     disabledParkingSpots: disabledParkingSpotsRef.current,
        //     level: Details.length
        // }
        // console.log("PAYLAOc ======", payload)

        if (isValidForm()) {
            if (true) {
                // console.log('correct', regular.split(',').length)
                if (map.type.split('/')[0] == 'video') {
                    console.log('first video')
                    dispatch(uploadVideo({
                        token: adminData?.token,
                        data: {
                            name: levelNameRef.current, regular: regularRef.current, electric: electricRef.current,
                            designated: designatedRef.current, entrance: entranceRef.current, map, parkingLotId: parkingLot?._id,
                            disabledParkingSpots: disabledParkingSpotsRef.current,
                            doubleParkingSpots: doubleParkingSpotsRef.current,
                            frozenParkingSpots: frozenSpotRef.current,
                            level: Details[0]?.level ? Details[0]?.level + 1 : 1
                        },
                        setNewRow: () => setNewRow(false)
                    }))
                } else {
                    console.log(' imagessss')
                    dispatch(uploadImage2({
                        token: adminData?.token,
                        data: {
                            name: levelNameRef.current, regular: regularRef.current, electric: electricRef.current,
                            designated: designatedRef.current, entrance: entranceRef.current, map, parkingLotId: parkingLot?._id,
                            disabledParkingSpots: disabledParkingSpotsRef.current,
                            doubleParkingSpots: doubleParkingSpotsRef.current,
                            frozenParkingSpots: frozenSpotRef.current,
                            level: Details[0]?.level ? Details[0]?.level + 1 : 1
                        },
                        setNewRow: () => setNewRow(false)
                    }))
                }
            } else {
                alert('Please Enter Correct Spots')
            }
        }
    }

    const handleEditParkingSpot = (item) => {
        levelNameRef.current = item?.name
        regularRef.current = item?.regularString
        electricRef.current = item?.electricString
        designatedRef.current = item?.designatedString
        entranceRef.current = item?.entrance
        disabledParkingSpotsRef.current = item?.disabledString
        doubleParkingSpotsRef.current = item?.doubleString
        frozenSpotRef.current = item?.frozenString
        setMap(item?.map)
        setEditableSpot(item)
    }

    const handleUpdateSpot = (item) => {
        let type = updatedMap?.type?.split('/')[0] == 'image' ? "IMAGE" : updatedMap?.type?.split('/')[0] == 'video' ? "VIDEO" : "OTHER"
        let payload = {
            token: adminData?.token,
            data: {
                level: item?.level, regular: regularRef.current, electric: electricRef.current,
                designated: designatedRef.current, entrance: entranceRef.current, map: (type == "IMAGE" || type == "VIDEO") ? updatedMap : map, parkingLotId: parkingLot?._id,
                disabledParkingSpots: disabledParkingSpotsRef.current,
                doubleParkingSpots: doubleParkingSpotsRef.current,
                frozenParkingSpots: frozenSpotRef.current,
                name: levelNameRef.current
            },
            levelId: item?._id,
            setEditableSpot: () => setEditableSpot(null)
        }
        if (isValidForm()) {
            if (true) {
                if (type == 'IMAGE') {
                    dispatch(uploadImage2(payload))
                } else if (type == 'VIDEO') {
                    dispatch(uploadVideo(payload))
                } else {
                    dispatch(updateLevel(payload))
                }
            } else {
                alert('Please Enter Correct Spots')
            }
        }
    }

    const handleDeleteSpot = (id) => {
        dispatch(deleteLevel({ token: adminData?.token, id: id }))
    }

    const ParkingSpotRow = ({ user, index, isNewRow, editableSpot, handleSaveSpot, handleUpdateSpot, handleDeleteSpot, handleEditParkingSpot }) => {
        const isEditable = editableSpot && editableSpot?._id === user?._id;

        const renderTableCell = (ref, type = 'text') => (
            <TableCell width={'13%'} align="center">
                <TextField
                    type={type}
                    defaultValue={ref.current}
                    onChange={(e) => (ref.current = e.target.value)}
                    variant="outlined"
                    size="small"
                    fullWidth
                />
            </TableCell>
        );

        return (
            <TableRow
                key={index}
                sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
            >
                {isNewRow || isEditable ? (
                    <>
                        {renderTableCell(levelNameRef)}
                        {renderTableCell(regularRef)}
                        {renderTableCell(electricRef)}
                        {renderTableCell(designatedRef)}
                        {renderTableCell(disabledParkingSpotsRef)}
                        {renderTableCell(doubleParkingSpotsRef)}
                        {renderTableCell(frozenSpotRef)}
                        {renderTableCell(entranceRef, 'number')}
                        <TableCell>
                            <div className='min-w-[80px] self-start'>
                                <InputFile name={'mapFile'} value={isEditable ? updatedMap || map : map} onChange={(e) => isEditable ? setUpdatedMap(e.target.files[0]) : setMap(e.target.files[0])} />
                            </div>
                        </TableCell>
                        <TableCell>
                            <FontIcon
                                handleClick={() => isEditable ? handleUpdateSpot(user) : handleSaveSpot()}
                                iconname="fa-solid fa-floppy-disk"
                                size={isEditable ? "sm" : "xl"}
                                className={`text-appLightGrey mt-0 hover:text-appSeaGreen hover:cursor-pointer ${isEditable ? '' : 'hover:text-appSeaGreen'}`}
                            />
                        </TableCell>
                    </>
                ) : (
                    <>
                        <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.name ? user?.name : '-'}</TableCell>
                        <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.regularString ? user?.regularString : '-'}</TableCell>
                        <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.electricString ? user?.electricString : '-'}</TableCell>
                        <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.designatedString ? user?.designatedString : '-'}</TableCell>
                        <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.disabledString ? user?.disabledString : '-'}</TableCell>
                        <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.doubleString ? user?.doubleString : '-'}</TableCell>
                        <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.frozenString ? user?.frozenString : '-'}</TableCell>
                        <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.entrance ? user?.entrance : '-'}</TableCell>
                        <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.map?.split('/')?.pop()}</TableCell>
                        <TableCell style={{ verticalAlign: 'top' }} sx={{ width: '20px' }}>
                            <FontIcon
                                handleClick={() => handleDeleteSpot(user?._id)}
                                iconname="fa-solid fa-trash-can"
                                size="sm"
                                className='text-appLightGrey mt-0 hover:text-appSeaGreen hover:cursor-pointer'
                            />
                            <FontIcon
                                handleClick={() => handleEditParkingSpot(user)}
                                iconname="fa-solid fa-pen"
                                size="sm"
                                className='text-appLightGrey mt-0 hover:text-appSeaGreen hover:cursor-pointer'
                            />
                        </TableCell>
                    </>
                )}
            </TableRow>
        );
    };

    return (
        <TableContainer sx={{
            boxShadow: 'none',
            maxHeight: '37vh',
        }} component={Paper}>
            <Table sx={{
                minWidth: 650,
                borderCollapse: 'collapse',
                '& th, & td': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000',
                    fontSize: '14px',
                    fontWeight: 300,
                },
                '& th': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000000',
                    fontSize: '15px',
                    fontWeight: 'bold',
                },
                '& td': {
                    maxWidth: '110px',
                    wordWrap: 'break-word',
                }
            }}
                aria-label="simple table">
                <TableHead >
                    <TableRow>
                        {
                            tableHeader.map((head, index) => {
                                return (
                                    <TableCell className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} `} key={index} align='center'>{head?.title}</TableCell>
                                )
                            })
                        }
                    </TableRow>
                </TableHead>
                <TableBody>
                    {Details.map((user, index) => (
                        <ParkingSpotRow
                            key={index}
                            user={user}
                            index={index}
                            isNewRow={isNewRow && !editableSpot && Details.length - 1 === index}
                            editableSpot={editableSpot}
                            handleSaveSpot={handleSaveSpot}
                            handleUpdateSpot={handleUpdateSpot}
                            handleDeleteSpot={handleDeleteSpot}
                            handleEditParkingSpot={handleEditParkingSpot}
                        />
                    ))}
                </TableBody>
            </Table>
        </TableContainer>
    )
}

export default SpotParking