"use client"
import { IMAGES, svgImages } from '@/utilities/utils';
import Image from 'next/image';
import React, { useEffect, useState } from 'react'
import Link from 'next/link';
import dynamic from 'next/dynamic';
import { useSelector, useDispatch } from 'react-redux';
import { setClearData } from '@/store/userSlice';
import { useRouter } from 'next/router';
import { useTranslation } from 'react-i18next';
import ToggleLanguageButton from './ToggleLanguageButton';
import i18n from '../../i18n';



const FontIcon = dynamic(() => import('./FontIcon'), { ssr: false })


function Navbar({ fullScreen, active, children }) {
    const { t } = useTranslation();
    const { adminData } = useSelector(state => state.user)
    const dispatch = useDispatch()
    const router = useRouter()
    const [sidebarOpen, setSidebarOpen] = useState(false);
    const [logoutbtn, setLogoutBtn] = useState(false)
    const [navbar, setNavBar] = useState(
        [
            {
                icon: active == 'dashboard' ? svgImages.dashboardlighted : svgImages.dashboardunlighted,
                name: 'dashboard',
                active: active == 'dashboard' ? true : false,
                url: '/dashboard',
                hidden: false
            },
            {
                icon: active == 'users' ? svgImages.usersHighlighted : svgImages.usersUnhighlighted,
                name: 'users',
                active: active == 'users' ? true : false,
                url: '/users',
                hidden: false
            },
            {
                icon: active == 'announcement' ? svgImages.maillighted : svgImages.mailunlighted,
                name: 'announcement',
                active: active == 'announcement' ? true : false,
                url: '/createAnnouncement',
                hidden: false

            },
            {
                icon: active == 'parkinglot' ? svgImages.carlighted : svgImages.carunlighted,
                name: 'parkinglot',
                active: active == 'parking lots' ? true : false,
                url: '/parkingLots',
                hidden: false

            },
            {
                icon: active == 'report' ? svgImages.chartlighted : svgImages.chartunlighted,
                name: 'report',
                active: active == 'report' ? true : false,
                url: '/faultReports',
                hidden: false

            },
            {
                icon: active == 'monitoring' ? svgImages.monitorHighlited : svgImages.monitoringIcon,
                name: 'monitoring',
                active: active == 'monitoring' ? true : false,
                url: '/monitoring',
                hidden: false
            },
            {
                icon: active == 'shabat' ? svgImages.holidayIcon : svgImages.holidayIconUpdated,
                name: 'shabat',
                active: active == 'shabat' ? true : false,
                url: '/shabatScreen',
                hidden: adminData?.admin?.role == 'admin' ? false : true
            },
            {
                icon: active == 'admin' ? svgImages.adminlighted : svgImages.adminunlighted,
                name: 'admin',
                active: active == 'admin' ? true : false,
                url: '/adminUsers',
                hidden: adminData?.admin?.role == 'admin' ? false : true
            },

        ]
    )

    const toggleSidebar = () => {
        setSidebarOpen(!sidebarOpen);
        if (logoutbtn) {
            setLogoutBtn(false)
        }
    };

    const toggleLogOutBtn = () => {
        setLogoutBtn(!logoutbtn)
    }

    const handleLogOut = () => {
        router.push('/')
        console.log('log out')
        setTimeout(() => {
            dispatch(setClearData())

        }, 500);
    }

    useEffect(() => {
        const { config } = require('@fortawesome/fontawesome-svg-core');
        config.autoAddCss = false;
    });



    return (
        <div className='flex flex-row bg-appLightGrey w-screen h-screen '>
            {!fullScreen && <div onMouseEnter={() => setSidebarOpen(true)} onMouseLeave={() => { setSidebarOpen(false); setLogoutBtn(false) }} className={`bg-appWhite  z-20 text-white h-screen overflow-hidden overflow-y-auto fixed ${sidebarOpen ? 'w-[330px]' : 'w-[120px]'} transition-all duration-300 ${sidebarOpen ? 'ml-0' : '-ml-0'}`}>
                <div className={`flex flex-col py-4  select-none w-full justify-around ${i18n.language == 'he' ? 'mr-[25px]' : 'ml-[25px]'}   h-full`}>
                    <Image onClick={() => router.push('/dashboard')} className='invert cursor-pointer hover:filter-invert-sepia-saturate-hue duration-200' alt='side bar logo' height={77} width={69} src={svgImages.sidebarlogo} />
                    <div className={`flex mt-10  self-start h-7 ${i18n.language == 'he' ? 'mr-[28px]' : 'ml-[28px]'} gap-[52px]`}>
                        <FontIcon handleClick={toggleSidebar} iconname={`fa-solid  ${sidebarOpen ? 'fa-circle-chevron-left' : 'fa-circle-chevron-right'}`} className={`${sidebarOpen ? 'text-appSeaGreen' : 'text-appBlack'} self-center  hover:text-appSeaGreen rounded-full  ${!sidebarOpen && 'hover:shadow-md'}`} />
                        {sidebarOpen && <div>
                            <div onClick={toggleLogOutBtn} className='flex items-center group hover:cursor-pointer gap-2'>
                                <h2 className={`text-appBlack ${logoutbtn && 'text-appSeaGreen'} ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-[15px] py-1 text-start ${sidebarOpen ? 'ml-0' : '-ml-44'} min-w-[100px]  transition-all duration-300 group-hover:text-appSeaGreen`}>{adminData?.admin?.firstName}</h2>
                                <FontIcon iconname={`fa-solid ${logoutbtn ? 'fa-chevron-up' : 'fa-chevron-down'}`} className={`text-appBlack ${logoutbtn && 'text-appSeaGreen'}   group-hover:text-appSeaGreen`} />
                            </div>
                            {logoutbtn && <h2 onClick={handleLogOut} className='text-appBlack  cursor-pointer font-spartan font-normal pl-3 text-[15px] hover:text-appSeaGreen '>{t('logout')}</h2>}
                        </div>
                        }
                    </div>
                    <div className='h-[70%] mt-5'>
                        <div className=' h-[65%] flex flex-col justify-around'>
                            {
                                navbar.map((nav, index) => {
                                    return (
                                        !nav.hidden && <Link href={nav.url} key={index} className={`flex  self-start h-7 ${i18n.language == 'he' ? 'mr-[15px]' : 'ml-[20px]'}  gap-9`}>
                                            <Image alt='navbar icon' width={40} className={`object-contain ${(nav.name != active && nav.name != 'monitoring' && nav.name != 'shabat' && nav.name != 'users') && 'invert'}`} src={nav.icon} />
                                            {sidebarOpen && <h2 className={`${nav.active ? 'text-appSeaGreen' : 'text-appBlack'} ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'}  font-normal text-[15px] py-1 w-[220px]  ver ${sidebarOpen ? 'ml-0' : '-ml-44'} transition-all duration-300 hover:text-appSeaGreen `}>{nav.name == 'admin' ? t('adminnavtitle') : t(nav.name)}</h2>}
                                        </Link>
                                    )

                                })
                            }
                        </div>
                    </div>

                    <div className={`${i18n.language == 'en' ? '-ml-1' : '-mr-1'} w-[81px] flex flex-col items-center justify-center gap-5 `}>
                        <ToggleLanguageButton />
                        <Image alt='hebrewicon' className='w-full h-[25px] object-contain ' src={IMAGES.hebrewBtmlogo} />
                        <Image alt='ysb_logo' className='w-full h-[60px] invert object-contain ' src={IMAGES.YBS_Logo_grey} />
                    </div>
                </div>
            </div>}
            {active != 'monitoring' ? <div className={`${i18n.language == 'he' ? 'mr-[142px] ml-[22px]' : 'ml-[142px] mr-[22px]'} my-[24px]  w-full bg-appWhite rounded-[15px] shadow-appBlack15 shadow-lg overflow-hidden overflow-y-auto`}>
                {
                    children
                }
            </div> : <div className={`${!fullScreen && (i18n.language == 'he' ? 'mr-[120px]' : 'ml-[120px] ')} bg-appBlackOC w-full h-screen overflow-hidden`}>
                {children}
            </div>}
        </div>
    )
}

export default Navbar