import InputField from '@/components/InputField'
import Navbar from '@/components/navbar'
import { createTemporaryPassword, deleteUser, getParkingSpots, unlockUser, updateGuestUser, updateUser } from '@/store/userReducer'
import { InputLabel, MenuItem, Select } from '@mui/material'
import Autocomplete from '@mui/joy/Autocomplete';
import dynamic from 'next/dynamic'
import { useRouter } from 'next/router'
import React, { useEffect, useLayoutEffect, useState } from 'react'
import { useSelector, useDispatch } from 'react-redux';
import Loader from './Loader'
import moment from 'moment'
import Image from 'next/image'
import { IMAGES, apiUtility, svgImages } from '@/utilities/utils'
import Modal from '@/components/model'
import { useTranslation } from 'react-i18next'
import i18n from '../../i18n'
import { setFrom } from '@/store/userSlice';
import { Calendar } from '@nextui-org/calendar';
import { now } from "@internationalized/date";

const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })

const foundDesignatedSpots = new WeakMap()

function editUser({ route }) {
    const { t } = useTranslation()
    const { loader, from, allUsers, lotsCount, parkingSpots, parkingLots, adminData } = useSelector(state => state.user)
    const dispatch = useDispatch()
    const router = useRouter()
    const data = router.query.data ? JSON.parse(router.query.data) : null
    const disableGuestEdit = data?.disableEdit ?? true



    const [randomPassModel, setRandomPassModel] = useState(false)
    const [userDetail, setAdminDetail] = useState({
        name: data ? data?.firstName?.trim() : '',
        // registration: data?.vehicle ? data?.vehicle?.registration : '',
        phoneNumber: data?.phoneNumber ? data?.phoneNumber : {
            countryCode: "+972",
            number: ""
        },
        electricCharging: data?.isGuest ? data?.electricCharging : (data?.electricCharging ? 'Yes' : 'No'),
        email: data?.email ? data?.email : '',
        createTemporaryPassword: '',
        accessibleParkingSpot:data?.isGuest ? data?.disabled : (data?.disabled ? 'Yes' : 'No')
    });
    const [showCalender, setShowCalender] = useState(false)
    const [formatedDate, setFormatedDate] = useState(data?.userPresenceDate)
    const [selectedDate, setSelectedDate] = useState(now())

    const allowedlot = {
        parkinglot: '',
        designatedParkingSpot: '',
        designatedParkingSpotOptions: []
    }

    const designatedParkingData = data?.parkingLots?.map(parkingLot => {
        const designatedSpot = data?.designatedParkingSpot?.find(spot => spot?.parkingLot?._id === parkingLot?._id && !foundDesignatedSpots.has(spot) );
        if(designatedSpot) foundDesignatedSpots.set(designatedSpot,designatedSpot?.parkingCode)
        const designatedParkingSpot = designatedSpot ? designatedSpot : { _id: '1', parkingCode: 'No' };
        const designatedParkingSpotOptions = designatedSpot ? [...parkingLot?.designatedSpots, designatedSpot] : [...parkingLot?.designatedSpots];
        return {
            designatedParkingSpot,
            parkinglot: parkingLot?._id,
            designatedParkingSpotOptions: designatedParkingSpotOptions?.sort((a, b) => (a.parkingCode > b.parkingCode) ? 1 : -1)
        };
    });

    const [allowedLots, setAllowedLots] = useState(designatedParkingData ? designatedParkingData : [allowedlot])
    const [mainParkingLot, setMainParkingLot] = useState(data?.mainParkingLot)

    const vehicle = {
        user: data?._id,
        make: "",
        model: "",
        registration: ""
    }
    const [vehicles, setVehicles] = useState(data?.vehicles ? data?.vehicles : [vehicle])

    let mainParkingLotconfig = {
        key: 'mainparkinglot', type: 'select', options: parkingLots?.parkingLots?.filter(obj => allowedLots?.some(item => item.parkinglot === obj._id)) || []
    }

    const allowedlotsconfig = [
        { key: 'parkinglot', type: 'select', options: parkingLots?.parkingLots || [] },
        { key: 'designatedParkingSpot', type: 'select', options: [] },
    ]

    const formConfig = [
        { key: 'name', label: 'Name', type: 'text' },
        // { key: 'registration', label: 'Vehicle Number', type: 'text' },
        { key: 'phoneNumber', label: 'Phone Number', type: 'text' },
        { key: 'email', label: 'Email', type: 'email' },
        { key: 'electricCharging', label: 'Electric Charging', type: data?.isGuest ? 'checkbox' : 'select', options: ['Yes', 'No'] },
        { key: 'accessibleParkingSpot', label: 'Accessible Parking Spot', type: data?.isGuest ? 'checkbox' : 'select', options: ['Yes', 'No'] },
        data?.isGuest ? { type: 'empty' } : { key: 'createTemporaryPassword', label: 'createTemporaryPasswordbtntext', type: 'tempPass' },
        data?.isGuest ? { type: 'empty' } : { key: 'unlockUser', label: 'unlockUser', type: 'tempPass' },
        { type: 'empty' },
        { type: 'empty' },
    ];

    const isFormValid = () => {
        const {
            firstName,
            // registration,
            phoneNumber,
            electricCharging,
            // email,
            accessibleParkingSpot
        } = userDetail;

        const isAllFilled = allowedLots.every(row =>
            Object.values(row).every(value => value !== '')
        );

        const isAllVehiclesFilled = vehicles.every(row =>
            row.registration.trim() !== ''
        );

        const requiredFieldsFilled =
            firstName !== '' &&
            // registration !== '' &&
            phoneNumber.countryCode !== '' &&
            phoneNumber.number !== '' &&
            electricCharging !== '' &&
            // email !== '' &&
            accessibleParkingSpot !== '' &&
            mainParkingLot !== '';


        if (requiredFieldsFilled && isAllFilled && isAllVehiclesFilled) {
            return true;
        } else {
            console.log('Please fill in all required fields.');
            return false;
        }
    };

    const arraysAreEqual = (arr1, arr2) => {
        if (arr1.length !== arr2.length) {
            return false;
        }

        for (let i = 0; i < arr1.length; i++) {
            const obj1 = arr1[i];
            const obj2 = arr2[i];

            // Compare individual object properties
            for (let key in obj1) {
                if (obj1.hasOwnProperty(key)) {
                    // Check if the property is an object
                    if (typeof obj1[key] === 'object' && obj1[key] !== null) {
                        if (!arraysAreEqual([obj1[key]], [obj2[key]])) {
                            return false;
                        }
                    } else if (obj1[key] !== obj2[key]) {
                        return false;
                    }
                }
            }
        }

        return true;
    }

    const handleChangeAllowedLot = async (value, index, key) => {
        const updatedLots = [...allowedLots];
        updatedLots[index][key] = value;
        setAllowedLots(updatedLots);
        if (key == 'parkinglot') {
            dispatch(getParkingSpots({
                token: adminData?.token, parkingLotId: value, fromCreate_UpdateUser: true,
                setAllowedLots, allowedLots, index, isAvailable: true, type: 'designated',
                designatedParkingSpot: data?.designatedParkingSpot,
                parkinglots: data?.parkingLots
            }))
        }
    };

    const handleDeleteLot = (id) => {
        const lots = allowedLots.filter((item, index) => index != id)
        setAllowedLots(lots)
    }

    const handleChange = (e, key) => {
        setAdminDetail({
            ...userDetail,
            [key]: key == 'phoneNumber' ? { ...userDetail?.phoneNumber, number: e.target.value } : e.target.value,
        });
    };

    const handleVehicleChange = (e, index) => {
        const updatedVehicles = [...vehicles]
        updatedVehicles[index]['registration'] = e.target.value
        setVehicles(updatedVehicles)
    }

    const handleSubmit = (e) => {
        e.preventDefault();
        if (isFormValid()) {
            if (data?.isGuest) {
                const checkEquality = arraysAreEqual(
                  allowedLots,
                  designatedParkingData
                );
                if (checkEquality && disableGuestEdit) {
                  alert(t("alerteditguestuser"));
                  return;
                }

                const updatePayload = disableGuestEdit ? {} : {
                    ...userDetail,
                    mainParkingLot,
                    disabled:userDetail.accessibleParkingSpot,
                    parkingLots,
                    vehicles:arraysAreEqual(data?.vehicles ?? [],vehicles)?null:vehicles,
                    firstName:userDetail.name,
                    reservationDate:moment(data?.userPresenceDate).isSame(moment(formatedDate)) ? null : moment(formatedDate).toDate()
                }
                dispatch(
                  updateGuestUser({
                    ...updatePayload,
                    allowedLots: checkEquality 
                      ? null
                      : allowedLots,
                    userId: data?._id,
                    userName: data?.firstName,
                    disableGuestEdit,
                    alert: (msg) => alert(msg),
                    checkParkingLots: data?.parkingLots,
                  })
                );
            
            } else {
                dispatch(updateUser({
                    data: userDetail, allowedLots: arraysAreEqual(allowedLots, designatedParkingData) ? null : allowedLots,
                    mainParkingLot: mainParkingLot, userId: data?._id, vehicles: vehicles, vehicleId: data?.vehicle?._id, token: adminData?.token, setAdminDetail: () => setAdminDetail({
                        name: '',
                        registration: '',
                        phoneNumber: {
                            countryCode: "+972",
                            number: ""
                        },
                        electricCharging: '',
                        email: '',
                        createTemporaryPassword: ''
                    }),
                    alert: (msg) => alert(msg)
                }))
            }
        }
        // console.log('Form submitted:', userDetail,mainParkingLot,allowedLots);
    };

    const handleAlert = (msg) => {
        alert(msg);
    }

    const handleTempPassword = () => {
        dispatch(createTemporaryPassword({ data: { phoneNumber: data?.phoneNumber }, alert: handleAlert }))
        setRandomPassModel(false)
    }

    const handleDeleteUser = () => {
        dispatch(deleteUser({ token: adminData?.token, id: data?._id }))
    }

    const handleDeleteVehicle = (id) => {
        const updatedVehicles = vehicles.filter((item, index) => index != id)
        setVehicles(updatedVehicles)
    }

    const handleBtnClick = (key) => {
        if (key == 'createTemporaryPassword') {
            setRandomPassModel(true)
        } else if (key == 'unlockUser') {
            dispatch(unlockUser({ id: data?._id, token: adminData?.token }))
        }

    }

    useEffect(() => {
        if (!data) {
            if (from) {
                router.push('/monitoring')
            }
             else {
                router.push('/users')
            }
        }
    }, []);

    useEffect(() => {
        router.query.from == 'monitoring' && dispatch(setFrom('monitoring'))
    }, [])

    useEffect(() => {
        if (adminData?.token == undefined) {
            setTimeout(() => {
                router.push('/')
            }, 1000);
        }
    }, [adminData])

    useEffect(() => {
        if (data && !allowedLots?.some(obj => obj?.parkinglot == mainParkingLot)) {
            setMainParkingLot('')
        }
    }, [allowedLots])

    useEffect(() => {
        setFormatedDate({
            ...selectedDate,
            month: selectedDate?.month - 1
        })
    }, [selectedDate])
    
    if (adminData?.token == undefined) {
        return <Loader />
    }

    return (
        <>
            <Navbar active={'users'}>
                {loader && <Loader />}
                <div className='flex flex-row items-center justify-between  mt-8 mx-12'>
                    <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[30px] select-none  `}>{t('edituser')}</h1>
                    <div className='flex gap-7'>
                        {/* {
                            !data?.isGuest && (
                                <FontIcon handleClick={() => handleDeleteUser()} size='xl' iconname="fa-solid fa-trash-can" className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen' />
                            )
                        } */}
                        <FontIcon handleClick={() => {
                            if (!disableGuestEdit) {
                              router.push( {
                                pathname:'/dashboard',
                                query: {
                                  tabShow: true,
                                },
                              });
                              return;
                            }

                            router.back();
                        }} size='xl' iconname='fa-solid fa-xmark' className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen' />
                    </div>
                </div>
                <form onSubmit={handleSubmit} className='flex flex-col  gap-0 justify-center mx-11 mt-[55px] '>
                    <div className='flex gap-2'>
                        <div className='flex w-full items-center  justify-around gap-1 flex-wrap'>
                            {formConfig.map((config, index) => (
                                <div className='flex flex-col  w-[30%] self-start' key={index}>
                                    <InputLabel className={`font-normal text-[15px] ${i18n.language != 'en' ? 'font-rubik' : 'font-spartan'}  text-appBlack`} htmlFor={config.key}>{config.type != 'checkbox' && t(config.key)}</InputLabel>
                                    {config.type === 'select' ? (
                                        <Select
                                            required
                                            id={config.key}
                                            name={config.key}
                                            disabled={(config.key == 'designatedParkingSpot' && (userDetail.designatedParkingSpotSet == 'No' || userDetail?.designatedParkingSpotSet == '')) || (config.key == 'mainParkingLot' && userDetail?.allowedParkingLots?.length == 0) || (config.key == 'designatedParkingSpotSet' && userDetail?.mainParkingLot == '') ? true : false}

                                            value={userDetail[config.key]}
                                            onChange={(e) => handleChange(e, config.key)}
                                            className="mt-2  w-full rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                                            displayEmpty
                                            multiple={config.key == 'allowedParkingLots'}
                                        >
                                            <MenuItem value="" disabled>
                                                {t('adminSelectoption')}
                                            </MenuItem>
                                            {config.options.map((option, index) => (
                                                <MenuItem key={index} value={(config.key == 'allowedParkingLots' || config.key == 'mainParkingLot' || config.key == 'designatedParkingSpot') ? option?._id : option}>
                                                    {option?.parkingCode || option?._id ? (option?.parkingCode || option?.name) : option}
                                                </MenuItem>

                                            ))}
                                        </Select>
                                    ) : config.type === 'empty' ? null : config.type == 'tempPass' ? <button type='button' onClick={() => { handleBtnClick(config.key) }} className='bg-appLightGrey text-center mt-2 text-appWhite self-start rounded-full font-spartan font-normal text-[15px] px-4 py-[3px] hover:bg-appSeaGreen '>{t(config.label)}</button> : config.type == 'checkbox' ? <div className='flex items-center gap-2'>
                                        <Image onClick={() => {
                                            if (!data?.isGuest) {
                                                handleChange({
                                                    target: {
                                                        value: !userDetail[config.key]
                                                    }
                                                }, config.key)
                                            }
                                        }} alt='checkbox icon' className='w-6 h-6 cursor-pointer' src={userDetail[config.key] ? svgImages.dropdowncheckbox : svgImages.dropdownuncheckedcheckbox} />
                                        <p className={`font-normal text-[15px] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} text-appBlack`}>{config.type == 'checkbox' && t(config.key)}</p>
                                    </div> : (
                                        <InputField
                                            required={config.key == 'designatedParkingSpot' && userDetail?.designatedParkingSpotSet == 'Yes' ? true : false}
                                            disabled={(data?.isGuest && disableGuestEdit) || (config.key == 'designatedParkingSpot' && userDetail?.designatedParkingSpotSet != 'Yes')}
                                            type={config.type}
                                            id={config.key}
                                            name={config.key}
                                            value={config.key == 'phoneNumber' ? userDetail[config.key]?.number : userDetail[config.key]}
                                            onChange={(e) => handleChange(e, config.key)}
                                        />
                                    )
                                    }
                                    <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-[11px] pt-1 ${userDetail[config.key] == '' && config.type != 'tempPass' ? 'visible' : 'invisible'}`}>{(config.type !== 'checkbox' && config.key !== 'email' && (config.key != 'designatedParkingSpot' || userDetail?.designatedParkingSpotSet == 'Yes')) && t('fillalert')}</p>
                                </div>
                            ))}
                        </div>

                       

                   
                        <div className='font-spartan font-normal text-[15px] text-appBlack w-[20%] '>
                            {data?.isGuest != true && <InputLabel className={`${i18n.language == 'en' ? 'font-spartan font-normal' : 'font-rubik  font-medium'} text-[15px] text-appBlack`}>{t('accountlocked')}</InputLabel>}
                            {data?.isGuest != true && <div className=' py-4 shadow-xl border-t-[0.5px] overflow-hidden rounded-2xl max-h-[80%] w-[75%] overflow-y-auto'>
                                <h1 className={`text-center ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[15px] pb-5`}>{t('date')}</h1>
                                {
                                    data?.accountLockInstances?.map((date, index) => {
                                        return <p key={index} className='py-4 font-spartan font-normal text-[14px] text-center border-appSeaGreen border-t-[1px] w-[70%] mx-auto '>{moment(date).format('YYYY-MM-DD')}</p>
                                    })
                                }
                            </div>}
                        </div>
                    </div>

                    {
                            (data?.isGuest && !disableGuestEdit) && (
                                <div
                                onClick={() => {
                                    setShowCalender(true);
                                }}
                                >
                                <div className="flex flex-col gap-3 my-2 justify-start">
                                    <p
                                    className={`font-normal text-[15px] ${i18n.language == "en" ? "font-spartan" : "font-rubik"} mt-4  text-appBlack `}
                                    >
                                    {t("reservationDate")}
                                    </p>
                                    <div className="w-[17%]">
                                    <InputField
                                        required={false}
                                        type={"text"}
                                        value={moment(formatedDate)?.format("YYYY MMM DD")}
                                    />
                                    </div>
                                </div>
                                </div>
                            )
                    }

                    <div className='flex items-center justify-start gap-3'>
                        <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[22px] mt-5`}>{t('vehicles')} </h1>
                        <FontIcon handleClick={() => {
                                setVehicles([...vehicles, vehicle])
                        }} size='lg' iconname="fa-solid fa-circle-plus" className='text-appLightGrey rounded-full mt-4 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md ' />
                    </div>

                   
                    {
                        vehicles?.map((vehicle, index) => {
                            return (
                                <div key={index} className='flex gap-3 my-2 justify-start'>
                                    <p className={`font-normal text-[15px] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} mt-4  text-appBlack `}>{t('registration')}</p>
                                    <div className='w-[17%]'>
                                        <InputField
                                            required={false}
                                            type={'text'}
                                            disabled={data?.isGuest && disableGuestEdit}
                                            value={vehicle.registration}
                                            onChange={(e) => handleVehicleChange(e, index)}
                                        />
                                        {<p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[11px] pt-1 ${vehicle.registration == '' ? 'visible' : 'invisible'}`}>{t('fillalert')}</p>}
                                    </div>

                                    <FontIcon handleClick={() => { handleDeleteVehicle(index) }} className={`${((!data?.isGuest && disableGuestEdit) && vehicles?.length > 1) ? 'visible' : 'invisible'} mt-4 text-appLightGrey  rounded-full hover:cursor-pointer hover:text-appSeaGreen `} iconname={'fa-solid fa-trash-can'} size={'sm'} />
                                </div>
                            )
                        })
                    }

                    <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[22px] mt-0`}>{t('allowedParkingLotsnew')}:</h1>

                    <div className='w-[55%] '>
                        <div className='flex items-center justify-around py-3 border-b-[1px] border-appSeaGreen'>
                            <p className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[15px]`}>{t('parkingLot')}</p>
                            <p className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[15px]`}>{t('designatedparkingspotnew')}</p>
                        </div>

                        {allowedLots?.map((lot, index) => {
                            const parkingOptions = lot?.designatedParkingSpotOptions || [];
                            const optionsWithNo = [{ _id: '1', parkingCode: 'No' }, ...parkingOptions];
                            const isParkingLotAvailable = parkingLots?.parkingLots?.some(obj => obj?._id === lot?.parkinglot);
                            return (
                                <div key={index} class={`${((isParkingLotAvailable || allowedLots[index]['parkinglot'] == '')) ? 'flex' : 'hidden'} gap-10 items-center mt-2 border-b-[1px] border-appSeaGreen pb-3`}>
                                    {allowedlotsconfig?.map((lotConfig, configIndex) => {
                                        return (
                                            <div key={configIndex} className='w-full'>
                                                {lotConfig?.key != 'designatedParkingSpot' ? <Select
                                                    key={configIndex}
                                                    required={false}
                                                    disabled={(data?.isGuest && disableGuestEdit && index <= data?.parkingLots?.length - 1)}
                                                    value={allowedLots[index][lotConfig.key]}
                                                    onChange={(e) => handleChangeAllowedLot(e.target.value, index, lotConfig.key)}
                                                    className="mt-1 w-full rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                                                    displayEmpty
                                                    sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }}
                                                >
                                                    <MenuItem value='' disabled>
                                                        {t('adminSelectoption')}
                                                    </MenuItem>
                                                    {
                                                        lotConfig?.options?.map((option, optionIndex) => (
                                                            <MenuItem key={optionIndex} sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }} value={option?._id ? option?._id : option}>
                                                                {option?._id ? option?.name : option}
                                                            </MenuItem>
                                                        ))

                                                    }
                                                </Select> : <Autocomplete
                                                    key={configIndex}
                                                    value={allowedLots[index][lotConfig.key]}
                                                    onChange={(e, value) => handleChangeAllowedLot(value, index, lotConfig.key)}
                                                    options={(data?.isGuest ? parkingOptions : optionsWithNo)}
                                                    disabled={(data?.isGuest && disableGuestEdit && index <= data?.parkingLots?.length - 1) || allowedLots[index].parkinglot == ''}
                                                    getOptionLabel={(option) => option?.parkingCode ? option?.parkingCode : ''}
                                                    className='h-[43px] mt-1'
                                                    placeholder={t('adminSelectoption')}
                                                />}
                                                {/* <Select
                                                    key={index}
                                                    required={false}
                                                    value={allowedLots[index][lotConfig.key]}
                                                    onChange={(e) => handleChangeAllowedLot(e.target.value, index, lotConfig.key)}
                                                    className="mt-1 w-full rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                                                    displayEmpty
                                                    sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }}
                                                >
                                                    <MenuItem value='' disabled>
                                                        {t('adminSelectoption')}
                                                    </MenuItem>
                                                    {lotConfig?.key != 'designatedParkingSpot' ? lotConfig?.options?.map((option, optionIndex) => (
                                                        <MenuItem key={optionIndex} sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }} value={option?._id ? option?._id : option}>
                                                            {option?._id ? option?.name : option}
                                                        </MenuItem>
                                                    )) : optionsWithNo?.map((spot, index) => (
                                                        <MenuItem key={index} value={spot?._id}>
                                                            {spot?.parkingCode}
                                                        </MenuItem>
                                                    ))
                                                    }
                                                </Select> */}
                                                <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[11px] pt-1 ${(allowedLots[index][lotConfig.key] == '') ? 'visible' : 'hidden'}`} >{t('fillalert')}</p>
                                            </div>
                                        );
                                    })}
                                    <FontIcon handleClick={() => { handleDeleteLot(index) }} className={`${((!data?.isGuest && allowedLots?.length > 1) || (!(data?.isGuest && index <= data?.parkingLots?.length - 1))) ? 'visible' : 'invisible'} text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen `} iconname={'fa-solid fa-trash-can'} size={'sm'} />
                                </div>
                            );
                        })}

                        <FontIcon handleClick={() => setAllowedLots([...allowedLots, allowedlot])} size='xl' iconname="fa-solid fa-circle-plus" className='text-appLightGrey rounded-full mt-4 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md ' />
                    </div>

                    <p className={`${i18n.language == 'en' ? 'font-spartan font-normal' : 'font-rubik font-normal'} text-[15px] mt-10`}>{t('mainParkingLot')}</p>
                    <Select
                        required={false}
                        value={mainParkingLot}
                        disabled={data?.isGuest && disableGuestEdit}
                        onChange={(e) => setMainParkingLot(e.target.value)}
                        className="mt-1 w-[18%] rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                        displayEmpty
                        sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }}
                    >
                        <MenuItem value='' disabled>
                            {t('selectparkinglot')}
                        </MenuItem>
                        {
                            mainParkingLotconfig?.options?.map((option, index) => {
                                return (
                                    <MenuItem value={option?._id ? option?._id : option} key={index} sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }}>
                                        {option?.name}
                                    </MenuItem>
                                )
                            })
                        }
                    </Select>
                    <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[11px] pt-1 ${(mainParkingLot == '') ? 'visible' : 'invisible'}`}>{t('fillalert')}</p>

                    <div className='flex mb-10 mt-8 items-center justify-center'>
                        <button
                            type='submit'
                            className={`bg-transparent transition-all delay-100 hover:bg-appSeaGreen hover:text-appWhite px-3 h-[59px] text-appSeaGreen border-2 border-appSeaGreen  rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-bold font-spartan' : 'font-rubik font-medium'}  cursor-pointer `}
                        >
                            {t('createuser')}
                        </button>
                    </div>
                </form>


                <Modal isOpen={randomPassModel} onClose={setRandomPassModel} >
                    <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
                        <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
                    </div>
                    <Image onClick={() => setRandomPassModel(false)} className={`mt-5 mx-3 hover:cursor-pointer ${i18n.language != 'en' && 'rotate-180'}`} alt='backbtn' src={svgImages.modalbackbtn} />

                    <div className='w-[450px]'>
                        <p className='text-appBlack font-spartan font-normal text-center text-[18px] mt-4 px-0'>
                            {t('temppassedituser1')}<br />
                            {t('temppassedituser2')}

                        </p>
                    </div>
                    <div className='flex  mt-8 items-center justify-center'>
                        <button
                            onClick={() => handleTempPassword()}
                            className='bg-transparent mb-7 w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] font-bold font-spartan cursor-pointer '
                        >
                            {t('accept')}
                        </button>
                    </div>
                </Modal>
                {showCalender && <div className='absolute z-20 top-0 left-0 h-full w-full flex items-center justify-center bg-black bg-opacity-50'>
                <div className='bg-white  rounded-2xl py-1'>
                    <div className='px-2'>
                        <h3 className={`${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[22px]`}>{moment(formatedDate)?.format('MMM DD')}</h3>
                    </div>
                    <Calendar
                        dir='ltr'
                        showMonthAndYearPickers
                        minValue={now()}
                        value={selectedDate}
                        onChange={setSelectedDate}
                    />
                    <div className='flex items-center justify-center gap-3 my-1'>
                        <div onClick={() => (setShowCalender(false))} className='border-2 border-appnewdarkgreen h-[32px] rounded-full flex items-center justify-center cursor-pointer'>
                            <p className={`${i18n.language == 'en' ? 'font-spartan text-[14px]' : 'font-rubik text-[20px]'} font-medium  px-6 text-center text-appnewdarkgreen`}>
                                {t('guestcalendercancel')}
                            </p>
                        </div>
                        <div onClick={() => setShowCalender(false)} className='bg-appnewdarkgreen rounded-full h-[32px] flex items-center justify-center cursor-pointer'>
                            <p className={`${i18n.language == 'en' ? 'font-spartan text-[14px]' : 'font-rubik text-[20px]'} font-medium  px-6 text-center text-white`}>
                                {t('guestcalenderApproval')}
                            </p>
                        </div>
                    </div>
                </div>
            </div>}
            </Navbar>
        </>
    )
}

export default editUser