import React, { useEffect, useState } from 'react'
import Image from 'next/image'
import { useRouter } from 'next/router'
import { useSelector, useDispatch } from 'react-redux';
import { IMAGES } from '../utilities/utils'
import PasswordHeader from '@/components/passwordHeader'
import { forgetPassword } from '@/store/userReducer';
import Loader from './Loader';
import { setLogin } from '@/store/userSlice';
import { useTranslation } from 'react-i18next';
import ToggleLanguageButton from '@/components/ToggleLanguageButton';
import i18n from '../../i18n';

const ForgetPassword = () => {
  const { t } = useTranslation();
  const { forgetmsg, error, loader, } = useSelector(state => state.user)
  const dispatch = useDispatch()
  const router = useRouter()
  const [email, setEmail] = useState('')
  const [err, setErr] = useState('')

  const handleSubmit = (e) => {
    e.preventDefault()
    dispatch(forgetPassword(email))
  }

  useEffect(() => {
    if (error?.message == 'Admin not found.' || error?.message == 'Email must be a valid email.') {
      setErr(t('emailincorrect'))
    } else if (error?.message == 'Too many failed login attempts. Your account has been locked, please contact the administration.') {
      setErr(error.message)
    } else if (Object.keys(forgetmsg).length !== 0) {
      setErr('')
    }
  }, [forgetmsg, error])

  return (
    <>
      {loader && <Loader />}
      <div>
        <PasswordHeader />
        <Image alt='logo' src={IMAGES.lock} className='h-32 mt-14 mx-auto object-contain w-44' />
        <p className={`text-appBlack text-[22px] mx-auto mt-[43px] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal w-[460px] text-center`}>
          {t('forgetemail')}
        </p>
        <form onSubmit={handleSubmit}>
          <div className='flex items-center justify-center'>
            <div className='flex-col mt-8 w-[378px]'>
              <p className={`${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-appBlack text-[15px]`}>{t('email')}</p>
              <input
                required
                type='email'
                value={email}
                onChange={(e) => setEmail(e.target.value)}
                className='w-full mt-2.5 rounded-md bg-appOffWhite shadow-md h-[42px] px-2 custom-input'
              />
              <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-[11px] mt-2`} >{err != '' && err} </p>
            </div>
          </div>

          <div className='flex mt-[66px] mb-7 items-center justify-center'>
            <button
              type='submit'
              className={`bg-appSeaGreen w-[134px] h-[59px] bg-4EB9B1 text-white rounded-full text-center ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}  text-[22px]  cursor-pointer`}
            >
              {t('send')}
            </button>
          </div>
        </form>

        <style jsx>{`
          .custom-input:focus {
            border-color: #4EB9B1;
            outline: none;
            box-shadow: 0 0 0 2px rgba(78, 185, 177, 0.5);
          }
        `}</style>
      </div>
    </>
  )
}

export default ForgetPassword
