import EditParkingLots from '@/components/EditParkingLots'
import ParkingLotsList from '@/components/ParkingLotsList'
import Navbar from '@/components/navbar'
import dynamic from 'next/dynamic'
import React, { useEffect, useState } from 'react'
import { useSelector, useDispatch } from 'react-redux';
import Loader from './Loader'
import { useRouter } from 'next/router'
import { getAllAdmins, getParkingLots, getSmsSendTime } from '@/store/userReducer'
import { useTranslation } from 'react-i18next'
import ToggleLanguageButton from '@/components/ToggleLanguageButton'
import i18n from '../../i18n'


const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })

function ParkingLots() {
    const { t } = useTranslation()
    const { adminData, loader, parkingLots } = useSelector(state => state.user)
    const dispatch = useDispatch()
    const router = useRouter()
    const [editParking, setEditParking] = useState(false)
    const [tableHeader, setTableHeader] = useState(
        [
            { title: t('parkinglotname') },
            { title: t('regularparkingspot') },
            { title: t('electricchargestation') },
            { title: t('savedparkingspots') },
            { title: t('accessible') },
            { title: t('maxReservationDistance') },
            { title: t('allotmentmethod') },
            { title: '' },

        ]
    )

    useEffect(() => {
        setTableHeader([
            { title: t('parkinglotname') },
            { title: t('regularparkingspot') },
            { title: t('electricchargestation') },
            { title: t('savedparkingspots') },
            { title: t('accessible') },
            { title: t('maxReservationDistance') },
            { title: t('allotmentmethod') },
            { title: '' },

        ])
    }, [i18n.language])


    useEffect(() => {
        if (adminData?.token == undefined) {
            setTimeout(() => {
                router.push('/')
            }, 1000);
        } else if (adminData?.token) {
            dispatch(getParkingLots({ token: adminData?.token, currentAdmin: adminData?.admin?._id }))
            dispatch(getSmsSendTime({ token: adminData?.token }))
        }
    }, [adminData])

    useEffect(() => {
        dispatch(getAllAdmins({ token: adminData?.token }))
    }, [])

    if (adminData?.token == undefined) {
        return <Loader />
    }


    return (
        <div>
            <Navbar active='parkinglot'>
                {loader && <Loader />}
                <div className='flex flex-row items-center justify-between mt-8 mx-12'>
                    <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}  text-[30px]   `}>{editParking ? t('createparkinglot') : t('parkinglot')}</h1>
                    <FontIcon handleClick={() => setEditParking(!editParking)} size='xl' iconname={`fa-solid ${editParking ? 'fa-xmark' : 'fa-circle-plus'}`} className={`text-appLightGrey rounded-full ${adminData?.admin?.role == 'sub-admin' ? 'invisible' : 'visible'} hover:cursor-pointer hover:text-appSeaGreen ${!editParking && 'hover:shadow-md'} `} />
                </div>
                {
                    !editParking ? <div className='max-w-full  rounded-2xl my-5 mx-5 shadow-xl pb-8' >
                        <div className=' mt-10 mx-10'>
                            <ParkingLotsList tableHeader={tableHeader} Details={parkingLots?.parkingLots ? parkingLots?.parkingLots : []} />
                        </div>
                    </div> :
                        <EditParkingLots setEditParking={() => setEditParking(false)} />
                }
            </Navbar>
        </div>
    )
}

export default ParkingLots