import Navbar from '@/components/navbar'
import React, { useEffect, useState } from 'react'
import Loader from './Loader'
import { useDispatch, useSelector } from 'react-redux'
import { useTranslation } from 'react-i18next'
import dynamic from 'next/dynamic'
import i18n from '../../i18n'
import ShabatList from '@/components/ShabatList'
import Modal from '@/components/model'
import { IMAGES, svgImages } from '@/utilities/utils'
import Image from 'next/image'
import { deleteHoliday, getAllHolidays } from '@/store/userReducer'
import CreateHoliday from '@/components/CreateHoliday'

const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })


const shabatScreen = () => {
    const { t } = useTranslation()
    const dispatch = useDispatch()
    const { loader, allHolidays, adminData } = useSelector(state => state.user)

    const [deleteHolidayModal, setDeleteHolidayModal] = useState(false)
    const [holidayId, setHolidayId] = useState('')
    const [createHoliday, setCreateHoliday] = useState(false)
    const [tableHeader, setTableHeader] = useState([
        { title: t('holidayName') },
        { title: t('holidayStart') },
        { title: t('holidayEnd') },
        { title: t('holidayEdit') },
        { title: t('holidayDelete') },
    ])

    const handleDeleteModal = (id) => {
        setHolidayId(id)
        setDeleteHolidayModal(true)
    }

    const handleDelete = () => {
        dispatch(deleteHoliday({ _id: holidayId }))
        setDeleteHolidayModal(false)
    }

    useEffect(() => {
        setTableHeader(
            [
                { title: t('holidayName') },
                { title: t('holidayStart') },
                { title: t('holidayEnd') },
                { title: t('holidayEdit') },
                { title: t('holidayDelete') },
            ]
        )
    }, [i18n.language])

    useEffect(() => {
        if (adminData?.token == undefined) {
            setTimeout(() => {
                router.push('/')
            }, 1000);
        } else if (adminData?.token) {
            dispatch(getAllHolidays())
        }
    }, [adminData])

    return (
        <>
            <Navbar active='shabat'>
                {loader && <Loader />}
                {!createHoliday ? <>
                    <div className='flex flex-row items-center justify-between mt-8 mx-12'>
                        <h1 className={`${i18n.language == 'en' ? "font-spartan font-bold " : "font-rubik font-medium"} text-[30px]`}>{t('shabat')}</h1>
                        <FontIcon handleClick={() => { setCreateHoliday(true) }} size='xl' iconname="fa-solid fa-circle-plus" className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md ' />
                    </div>
                    <div className='max-w-full  rounded-2xl my-5 mx-5 shadow-xl pb-8' >
                        <div className=' mt-10 mx-10'>
                            <ShabatList handleModal={handleDeleteModal} tableHeader={tableHeader} Details={allHolidays || []} />
                        </div>
                    </div>
                </> : <CreateHoliday setCreateHoliday={() => setCreateHoliday(false)} />
                }

            </Navbar>

            <Modal isOpen={deleteHolidayModal} onClose={setDeleteHolidayModal}>
                <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
                    <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
                </div>
                <Image onClick={() => { setDeleteHolidayModal(false) }} className={`mt-5 mx-3 ${i18n.language == 'he' && 'transform rotate-180'} hover:cursor-pointer`} alt='backbtn' src={svgImages.modalbackbtn} />

                <div className='w-[430px]'>
                    <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} px-5 font-normal text-center text-[18px] mt-4`}>
                        {t('deleteholidaymodal')}

                    </p>
                </div>
                <div className='flex mb-5  mt-8 items-center justify-center'>
                    <button
                        onClick={() => handleDelete()}
                        className={`bg-transparent w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}   cursor-pointer `}
                    >
                        {t('accept')}
                    </button>
                </div>
            </Modal>

        </>
    )
}

export default shabatScreen