import { IMAGES, svgImages } from '@/utilities/utils'
import Image from 'next/image'
import { useCallback, useEffect, useRef, useState } from 'react'
import dynamic from 'next/dynamic'
import UserDetailsList from '@/components/UserDetailsList'
import Navbar from '@/components/navbar'
import CreateUser from '@/components/CreateUser'
import { useSelector, useDispatch } from 'react-redux'
import { deleteUser, exportUsersList, getAllAssociatedUsers, getAllUsers, getAssociateParkingLots, getParkingLots, guestUserSearch, uploadFile } from '@/store/userReducer'
import Loader from './Loader'
import { useRouter } from 'next/router'
import { useTranslation } from 'react-i18next'
import i18n from '../../i18n'
import InputField from '@/components/InputField'
import Modal from '@/components/model'
import Pagination from '@mui/material/Pagination'
import { setFrom, setGuestUserNameSuccess, setGuestUserSearch, setOccupancyDropdownSelectedParkingLot } from '@/store/userSlice'
import Single_MultipleSelectDropdown from '@/components/Single_MultipleSelectDropdown'
import SuccessAlert from '@/components/SuccessAlert'
import GuestUser from '@/components/GuestUser'
import { useMemo } from 'react'



const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })

const Users = () => {
    const { t } = useTranslation()
    //store
    const {
      loader,
      allUsers,
      adminData,
      parkingLots,
      associateParkingLots,
      guestUserNameSuccess,
      guestSearchUsers,
      occupancyDropdownSelectedParkingLot,
      associatedUsers
    } = useSelector((state) => state.user);

    const dispatch = useDispatch()
    const router = useRouter()

    const [showTab, setShowTab] = useState(false)
    const [createUser, setCreateUser] = useState(false)
    const [deleteUserModal, setDeleteUserModal] = useState(false)
    const [deleteUserId, setDeleteUserId] = useState(null)
    const [users, setUsers] = useState(allUsers?.users ? allUsers?.users : [])
    const [searchUsers, setSearchUsers] = useState('')
    const [sortType, setSortType] = useState('dsc')
    const inputRef = useRef(null)
    // const [debouncedSearchTerm] = useDebounce(searchUsers, 700);
    const fileInputRef = useRef(null);
    const [userPage, setUserPage] = useState(1)
    const [dropdownOpen, setDropdownOpen] = useState(false)
    const [selectedParkingLot, setSelectedParkingLot] = useState(null)
    const [multipleSelectedParkingLot, setMultipleSelectedParkingLot] = useState(associateParkingLots?.parkingLots ?? [])
    const [showSuccessAlert, setShowSuccessAlert] = useState(false)
    const fetchedAssociatedUsers = useRef(false)

    //memoization
    const filteredAssociatedUsers = useMemo(() => {
        // if(!multipleSelectedParkingLot || !multipleSelectedParkingLot.length) return associatedUsers?.users
        if(!associatedUsers?.users) return 
        const namesArray = multipleSelectedParkingLot.map(location => location.name);
        return associatedUsers?.users.filter(item => {
            return item.parkingLots.some(lotItem => namesArray.includes(lotItem.name));
        });
    }, [multipleSelectedParkingLot, associatedUsers?.users]);
    



    const handleIconClick = () => {
        fileInputRef.current.click();
    };

    const handleFileChange = (e) => {
        const selectedFile = e.target.files[0];
        dispatch(uploadFile({
            usersFile: selectedFile,
            token: adminData?.token,
            userFileStatus: true,
            alert: (data) => alert(data),
            language: i18n.language == 'en' ? 'en' : 'heb',
            alertMsg: t('verifycsv')
        }))
    };

    const [tableHeader, setTableHeader] = useState(
        [
            { title: t('drivername'), id: 'firstName' },
            { title: t('vehiclenumber'), id: 'registration' },
            { title: t('allowedparkinglots') },
            { title: t('saveparkinglot'), id: 'designated' },
            { title: t('userTableElectric') },
            { title: t('userTableHandi') },
            { title: t('phoneNumber'), id: 'phoneNumber' },
            { title: t('accountlockedstatus') },
            { title: t('firstlogin') },
            { title: '' },
            { title: '' },
        ]
    )

    const handleSorting = (item) => {
        setSortType(sortType == 'dsc' ? 'asc' : 'dsc')
        dispatch(getAllUsers({
            token: adminData?.token, params: {
                page: 1,
                limit: 100000,
                isAvailable: true,
                sort: sortType,
                sortBy: item?.id,
                search: ''
            },
        }))
    }

    const handleDeleteUser = () => {
        setDeleteUserModal(false)
        dispatch(deleteUser({ token: adminData?.token, id: deleteUserId, notBack: true }))
    }

    const handleExportUser = () => {
        dispatch(exportUsersList())
    }

    // useEffect(() => {
    //     if (debouncedSearchTerm) {
    //         inputRef.current.blur()
    //         if (showTab) {
    //             dispatch(guestUserSearch({
    //                 searchGuestUser: searchUsers,
    //                 focus: () => { inputRef.current.focus() }
    //             }))
    //         } else {
    //             dispatch(getAllUsers({
    //                 token: adminData?.token, params: {
    //                     page: 1,
    //                     limit: 100000,
    //                     isAvailable: true,
    //                     search: debouncedSearchTerm.length == 0 ? "" : debouncedSearchTerm
    //                 },
    //                 fromSearch: true,
    //                 focus: () => { inputRef.current.focus() }
    //             }))
    //         }

    //     }
    //     setUserPage(1)
    // }, [debouncedSearchTerm])

    const handleGetAllAssociatedUsers =()=>{
        if(!showTab) return
        dispatch(getAllAssociatedUsers({
            token: adminData?.token, params: {
                page: 1,
                limit: 100000,
                isAvailable: true,
                search: searchUsers,
                isGuest:false
            },
            fromSearch: true,
            focus: () => { inputRef.current.focus() }
        }))
        setUserPage(1)
    }
    

    const handleSearch = () => {
        inputRef.current.blur()
        if (showTab) {
            handleGetAllAssociatedUsers()
        } else {
            dispatch(getAllUsers({
                token: adminData?.token, params: {
                    page: 1,
                    limit: 100000,
                    isAvailable: true,
                    search: searchUsers,
                    ...(showTab ? {isGuest:false} : {})
                },
                fromSearch: true,
                focus: () => { inputRef.current.focus() }
            }))
            setUserPage(1)
        }
    }

    useEffect(()=>{
        const payload = {
            token: adminData?.token, params: {
                page: 1,
                limit: 100000,
                isAvailable: true,
                search: selectedParkingLot?.name,
            },
            fromSearch: true,
        }
        dispatch(getAllUsers(payload))
    },[selectedParkingLot?.name])

    //fetch on bootstrap
    useEffect(()=>{
        if(!showTab) return
        if(fetchedAssociatedUsers.current) return
       handleGetAllAssociatedUsers()
       fetchedAssociatedUsers.current=true
    },[showTab])

    useEffect(() => {
        setUsers(allUsers?.users)
        dispatch(setFrom(null))
    }, [allUsers])

    useEffect(() => {
        setTableHeader(
            [
                { title: t('drivername'), id: 'firstName' },
                { title: t('vehiclenumber'), id: 'registration' },
                { title: t('allowedparkinglots') },
                { title: t('saveparkinglot'), id: 'designated' },
                { title: t('userTableElectric') },
                { title: t('userTableHandi') },
                { title: t('phoneNumber'), id: 'phoneNumber' },
                { title: t('accountlockedstatus') },
                { title: t('firstlogin') },
                { title: '' },
                { title: '' },
            ]
        )
    }, [i18n.language])

    useEffect(() => {
        if (adminData?.token == undefined) {
            setTimeout(() => {
                router.push('/')

            }, 1000);
        } else if (adminData?.token) {
            setSearchUsers('')
            if (!showTab) {
                dispatch(getAllUsers({
                    token: adminData?.token, params: {
                        page: userPage,
                        limit: 100000,
                        isAvailable: true,
                        search: searchUsers,
                        sortBy: 'created'
                    },
                }))
                dispatch(getParkingLots({ token: adminData?.token, currentAdmin: adminData?.admin?._id }))
                dispatch(getAssociateParkingLots({ token: adminData?.token }))
                dispatch(setGuestUserSearch(null))
            }
        }
    }, [adminData, showTab, userPage])

    useEffect(() => {
        if (guestUserNameSuccess) {
            setShowSuccessAlert(true)
            setTimeout(() => {
                setShowSuccessAlert(false)
                setTimeout(() => {
                    dispatch(setGuestUserNameSuccess(null))
                }, 2200);
            }, 2000);
        }
    }, [guestUserNameSuccess])

    useEffect(() => {
        setSelectedParkingLot(occupancyDropdownSelectedParkingLot ? occupancyDropdownSelectedParkingLot : parkingLots?.parkingLots?.[0])
    }, [parkingLots])

    if (adminData?.token == undefined) {
        return <Loader />
    }

    return (
        <>
            <Navbar active='users' >
                {loader && <Loader />}
                {!createUser ? <>
                    <div className='flex items-center justify-between mt-[27px] mx-3'>
                        <div className='flex items-center justify-start gap-4'>
                            <h1 onClick={() => { setShowTab(false), setDropdownOpen(false) }} className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} ${!showTab ? 'border-b-2 border-appSeaGreen font-bold' : ' hover:border-b-2 hover:border-appSeaGreen duration-150 font-normal text-appdarkgreen'} cursor-pointer select-none  text-[22px] `}>{t('systemUsersTab')}</h1>
                            <h1 onClick={() => {if(showTab) return; setShowTab(true), setDropdownOpen(false),setMultipleSelectedParkingLot(associateParkingLots?.parkingLots) }} className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} ${showTab ? 'border-b-2 border-appSeaGreen font-bold' : ' hover:border-b-2 hover:border-appSeaGreen duration-150 font-normal text-appdarkgreen'} cursor-pointer select-none  text-[22px] `}>{t('guestUsersTab')}</h1>
                        </div>
                        {!showTab && <div className='flex items-center justify-between mx-4 flex-row-reverse gap-10'>
                            <div className='flex items-center justify-center gap-[15px]'>
                                <div className='relative flex items-center justify-center group'>
                                    <FontIcon handleClick={() => handleExportUser()} size='2xl' iconname="fa-solid fa-file-arrow-down" className='text-appLightGrey rounded-full invert hover:invert-0 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md' />
                                    <p className={`z-10 ${i18n.language == 'en' ? 'font-spartan -left-4' : 'font-rubik -left-[17px]'}  text-appWhite  text-[10px] absolute bg-appgreyBE px-2 py-0.5 rounded-md shadow-lg -bottom-14 invisible text-center group-hover:visible transition-opacity duration-300`}>{t('exportuser')}</p>
                                </div>

                                <div className='relative group'>
                                    <label htmlFor="fileInput">
                                        <FontIcon
                                            size='2xl'
                                            iconname="fa-solid fa-file-arrow-up"
                                            className='text-appLightGrey rounded-full invert hover:invert-0 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md'
                                        />
                                    </label>
                                    <input
                                        type="file"
                                        id="fileInput"
                                        accept='.csv'
                                        ref={fileInputRef}
                                        style={{ display: 'none' }}
                                        onChange={handleFileChange}
                                    />
                                    <p
                                        className={`z-10 ${i18n.language == 'en' ? 'font-spartan -left-4' : 'font-rubik -left-[17px]'} text-appWhite  text-[10px] absolute bg-appgreyBE px-2 py-0.5 rounded-md shadow-lg -bottom-14  invisible text-center group-hover:visible transition-opacity duration-300`}
                                    >
                                        {t('importuser')}
                                    </p>
                                </div>

                                <div className='relative flex items-center justify-center group'>
                                    <FontIcon handleClick={() => setCreateUser(true)} size='xl' iconname="fa-solid fa-circle-plus" className='text-appLightGrey rounded-full invert hover:invert-0 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md group-hover:text-opacity-100' />
                                    <p className={`z-10 ${i18n.language == 'en' ? 'font-spartan -left-2' : 'font-rubik'} text-appWhite  text-[10px] absolute bg-appgreyBE px-2 py-0.5 rounded-md shadow-lg -bottom-10 invisible text-center group-hover:visible transition-opacity duration-300`}>{t('adduser')}</p>
                                </div>
                            </div>
                            {allUsers?.totalPages >= 1 && <div className={`flex px-10 justify-end ${i18n.language == 'en' ? 'border-r border-R-appgrey95' : 'border-l border-l-appgrey95'} `}>
                                <Pagination
                                    dir='ltr'
                                    count={allUsers?.totalPages}
                                    page={userPage}
                                    onChange={(e, value) => setUserPage(value)}
                                    showFirstButton={userPage != 1}
                                    showLastButton={allUsers?.totalPages != 0 && userPage != allUsers?.totalPages}
                                    hideNextButton={allUsers?.totalPages == 0 || userPage == allUsers?.totalPages}
                                    hidePrevButton={userPage == 1}
                                    sx={{
                                        '& .MuiPaginationItem-page.Mui-selected': {
                                            backgroundColor: '#4EB9B1',
                                        },
                                    }}
                                />
                            </div>}
                        </div>}
                    </div>

                    <div className='flex items-center mx-5 mt-6 gap-5'>
                        <div className={`relative  w-[76%]`}>
                            <InputField onKeyPress={(e) => { if (e.key == 'Enter') { handleSearch() } }} from='searchUser' inputRef={inputRef} value={searchUsers} onChange={e => { setSearchUsers(e.target.value); }} />
                            <Image onClick={() => { handleSearch() }} alt='searchiconimg' width={48} height={48} className={`absolute cursor-pointer top-[5px] ${i18n.language == 'en' ? 'right-1' : 'left-1'}`} src={svgImages.searchUserIcon} />
                        </div>
                        <div className={`h-[56px] w-[21%] ${dropdownOpen ? 'bg-appnewdarkgreen duration-200' : 'bg-Lightbluegray duration-150'}  rounded-[28px] flex items-center justify-center relative`}>
                            <Single_MultipleSelectDropdown
                                parkingLots={showTab ? (associateParkingLots?.parkingLots || []) : (parkingLots?.parkingLots || [])}
                                setDropdownOpen={() => setDropdownOpen(!dropdownOpen)}
                                setSelectedParkingLot={(parkingLot) => showTab ? setMultipleSelectedParkingLot(parkingLot) : (setSelectedParkingLot(parkingLot), dispatch(setOccupancyDropdownSelectedParkingLot(parkingLot)))}
                                dropdownOpen={dropdownOpen}
                                selectedParkingLot={showTab ? multipleSelectedParkingLot : selectedParkingLot}
                                dropDownType={showTab ? 'multiSelect' : 'singleSelect'}
                            />
                        </div>
                    </div>

                    {!showTab ? <div className='max-w-full rounded-2xl mt-5 mx-5 shadow-[0px_4px_30px_10px_#00000015] mb-8 ' >
                        <div className='mt-2 max-w-full mx-10'>
                            <UserDetailsList sortType={sortType} height={'74vh'} setDeleteUserModal={(user) => { setDeleteUserModal(true); setDeleteUserId(user?._id) }} sorting={(item) => handleSorting(item)} tableHeader={tableHeader} Details={users ? users : []} />
                        </div>
                    </div> : <div className='mx-3 mt-7 border-t border-appSeaGreen'>
                        <GuestUser guestUser={filteredAssociatedUsers} />
                    </div>
                    }
                </> : <CreateUser setCreateUser={() => { setCreateUser(false) }} />
                }


                <SuccessAlert showAlert={showSuccessAlert} message={t('newDesignSuccesAlert') + ' '} parkingLotsName={guestUserNameSuccess} />
                <Modal isOpen={deleteUserModal} onClose={setDeleteUserModal} >
                    <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
                        <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
                    </div>
                    <Image onClick={() => setDeleteUserModal(false)} className={`mt-5 mx-3 ${i18n.language == 'he' && 'rotate-180 '} hover:cursor-pointer`} alt='backbtn' src={svgImages.modalbackbtn} />

                    <div className='w-[450px]'>
                        <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-center text-[18px] mt-4 px-0`}>
                            {t('deleteUserModalText')}
                        </p>
                    </div>
                    <div className='flex  mt-8 items-center justify-center'>
                        <button
                            onClick={() => handleDeleteUser()}
                            className='bg-transparent mb-7 w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] font-bold font-spartan cursor-pointer '
                        >
                            {t('accept')}
                        </button>
                    </div>
                </Modal>
            </Navbar >
        </ >
    )
}

export default Users