import { addTime, apiUtility, getCorrectDateTime } from '@/utilities/utils';
import { createAsyncThunk } from '@reduxjs/toolkit';
import axios from 'axios';
import { setAdminData, setError, setForget, setGuestUserNameSuccess, setLoader, setNewPass } from './userSlice';
import store from './store';
import Router from "next/router";
import i18n from '../../i18n';

const loginAdmin = createAsyncThunk('user/adminData', async (payload) => {
    try {
        const response = await axios.post(apiUtility.baseURL + 'admins/login', payload)
        if (response.status === 200) {
            store.dispatch(getAllAdmins({ token: response?.data?.token, id: response?.data?.admin?._id }));
            store.dispatch(getFaultReport({ token: response?.data?.token, id: response?.data?.admin?._id }));
            // store.dispatch(getAllUsers({
            //     token: response?.data?.token, params: {
            //         page: 1,
            //         limit: 100000,
            //         isAvailable: true,
            //         search: '',
            //         sortBy: 'created'
            //     }
            // }));
            store.dispatch(getParkingLots({ token: response?.data?.token, currentAdmin: response?.data?.admin?._id }))
            store.dispatch(lotCount({ token: response?.data?.token, pagenumber: 1, limit: 4, id: response?.data?.admin?._id }))
            Router.push("/dashboard");
            return response?.data;
        }
    } catch (err) {
        console.log('Reducer : error loginAdmin === ', err?.response?.data)
        store.dispatch(setError(err?.response?.data))
        store.dispatch(setAdminData({}))
    }
})

const forgetPassword = createAsyncThunk('user/forgetPassword', async (payload) => {
    try {
        const response = await axios.post(apiUtility.baseURL + 'admins/forgot-password', { email: payload, isDev: false })
        if (response.status == 201) {
            Router.push("/newPassword");
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error forgetPassword === ', err)
        store.dispatch(setError(err?.response?.data))
        store.dispatch(setForget({}))

    }
})

const newPassword = createAsyncThunk('user/newPassword', async (payload) => {
    try {
        const response = await axios.post(apiUtility.baseURL + 'admins/login-temporary-password', payload)
        if (response?.status == 200) {
            Router.push("/passwordUpdated");
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error newPassword === ', err)
        store.dispatch(setError(err?.response?.data))
        store.dispatch(setNewPass({}))
    }
})

const getAllAdmins = createAsyncThunk('user/allAdmins', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `admins?page=1&limit=150&currentAdmin=${payload?.id ? payload?.id : store.getState().user.adminData.admin._id}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response?.status == 200) {
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from allAdmins', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const deleteAdmin = createAsyncThunk('user/deleteAdmin', async (payload) => {
    try {
        const response = await axios.delete(apiUtility.baseURL + `admins/${payload?.id}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            store.dispatch(getAllAdmins({ token: payload?.token }))
        }
    } catch (err) {
        console.log('Reducer : error from delete Admin ====', err)
    }

})

const createAdmin = createAsyncThunk('user/createAdmin', async (payload) => {
    try {
        const dataObj = {
            ...payload?.data,
            middleName: "",
            lastName: "",
            generateRandom: true,
            currentAdmin: payload?.id
        }
        console.log('get state ifd ====', store.getState().user?.adminData)
        const response = await axios.post(apiUtility.baseURL + 'admins', dataObj, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        console.log('response create admin ====', response)
        if (response?.status == 201) {
            store.dispatch(getAllAdmins({ token: payload?.token }));
            payload?.setCreateAdmin()
            payload?.clearFields()
            return response
        }
    } catch (err) {
        console.log('Reducer : error from create Admin ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
        if (err?.response?.status == 400) {
            payload?.alert(err?.response?.data?.message)
        }

    }
})

const getFaultReport = createAsyncThunk('user/faultReports', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `complaints?page=1&limit=150&currentAdmin=${payload?.id ? payload?.id : store.getState().user?.adminData?.admin?._id}&status=pending`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from fault report ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const addArchieve = createAsyncThunk('user/addArchieve', async (payload) => {
    try {
        const response = await axios.put(apiUtility.baseURL + `complaints/${payload?.id}`, { status: 'completed' }, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            store.dispatch(getFaultReport({ token: payload?.token }))
        }
    } catch (err) {
        console.log('Reducer : error from addArchieve report ====', err)

    }
})

const deleteFaultReport = createAsyncThunk('user/deleteReport', async (payload) => {
    try {
        const response = await axios.delete(apiUtility.baseURL + `complaints/${payload?.id}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            store.dispatch(getFaultReport({ token: payload?.token }))
        }
    } catch (err) {
        console.log('Reducer : error from delete fault report ====', err)

    }
})

const getParkingLots = createAsyncThunk('user/parkingLots', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `parking-lots?page=1&limit=150&currentAdmin=${payload?.currentAdmin}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        // console.log('response ===', response)
        if (response.status == 200) {
            return response.data
        }
    } catch (err) {
        console.log('Reducer : error from all parking lots ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})

const getAssociateParkingLots = createAsyncThunk('user/associateparkingLots', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `parking-lots?page=1&limit=100000`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        // console.log('response ===', response)
        if (response.status == 200) {
            return response.data
        }
    } catch (err) {
        console.log('Reducer : error from all parking lots ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})

const uploadImage = createAsyncThunk('user/uploadImage', async (payload) => {
    try {
        const dataObj = payload?.data
        const imgFormData = new FormData();
        typeof payload?.data?.accessMapFile == 'object' && imgFormData.append('images', payload?.data?.accessMapFile)
        typeof payload?.data?.avatar == 'object' && imgFormData.append('images', payload?.data?.avatar)

        const response = await axios.post(apiUtility.baseURL + 'upload-images', imgFormData, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'multipart/form-data',
            }
        })
        // console.log('response ====', response?.data)
        if (response.status == 201) {
            if (typeof payload?.data?.accessMapFile == 'object' && typeof payload?.data?.avatar == 'object') {
                dataObj.accessMapFile = response.data[0]
                dataObj.avatar = response.data[1]
            } else if (typeof payload?.data?.accessMapFile == 'object') {
                dataObj.accessMapFile = response.data[0]
            } else if (typeof payload?.data?.avatar == 'object') {
                dataObj.avatar = response.data[0]
            }
            if (!payload?.update) {
                console.log('at create parking lot api')
                store.dispatch(editParkingLot({ token: payload?.token, data: dataObj, id: payload?.id, }))
                // } else if (typeof payload?.data?.allotmentFile == 'object') {
                //     console.log('at  reducer call upload file api')
                //     store.dispatch(uploadFile({ token: payload?.token, data: dataObj, id: payload?.id, update: payload?.update, }))
            } else {
                store.dispatch(updateParkingLot({ data: dataObj, token: payload?.token, id: payload?.id }))
                console.log('at  reducer call update api')
            }
            return
        }
    } catch (err) {
        console.log('Reducer : error from upload images ====', err)
    }
})

const uploadFile = createAsyncThunk('user/uploadFile', async (payload) => {
    try {
        // console.log('running upload file ===', payload)
        const dataObj = payload?.data
        const fileFormData = new FormData();
        payload?.data?.allotmentFile && fileFormData.append('files', payload?.data?.allotmentFile)
        payload?.usersFile && fileFormData.append('files', payload?.usersFile)

        const response = await axios.post(apiUtility.baseURL + 'upload-files', fileFormData, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'multipart/form-data',
            }
        })
        if (response.status == 201) {
            payload?.data?.allotmentFile && (dataObj.allotmentFile = response.data[0])
            if (payload?.update) {
                console.log('here at upload file update api call')
                store.dispatch(updateParkingLot({ token: payload?.token, data: dataObj, id: payload?.id }))
            } else if (payload?.userFileStatus) {
                // console.log('response ===', response?.data[0].split('Spotpark-Backend/').pop())
                const usersUrl = response?.data[0].split('Spotpark-Backend/').pop()
                store.dispatch(createMultipleUser({
                    data: { fileUrl: usersUrl, lang: payload?.language },
                    token: payload?.token,
                    alert: payload?.alert,
                    alertMsg: payload?.alertMsg
                }))

            } else {
                store.dispatch(editParkingLot({ token: payload?.token, data: dataObj }))
            }
        }
    } catch (err) {
        console.log('Reducer : error from upload file ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})

const editParkingLot = createAsyncThunk('user/editparkinglot', async (payload) => {
    try {
        const time = addTime(payload?.data?.messageSendTime, payload?.data?.designatedReservationDuration)
        const dataObj = {
            ...payload?.data,
            absenceSendTime: time
        }
        const response = await axios.post(apiUtility.baseURL + 'parking-lots', dataObj, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 201) {
            store.dispatch(getParkingLots({ token: payload?.token, currentAdmin: store.getState().user?.adminData?.admin?._id }))
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from editParkingLot ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})

const updateParkingLot = createAsyncThunk('user/updateparkinglot', async (payload) => {
    try {
        const time = addTime(payload?.data?.messageSendTime, payload?.data?.designatedReservationDuration)
        const dataObj = {
            ...payload?.data,
            absenceSendTime: time
        }
        const response = await axios.put(apiUtility.baseURL + `parking-lots/${payload?.id}`, dataObj, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            store.dispatch(getParkingLots({ token: payload?.token, currentAdmin: store.getState().user?.adminData?.admin?._id }))
            Router.back()
            return
        }
    } catch (err) {
        console.log('Reducer : error from updateParkingLot ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})

const lotCount = createAsyncThunk('user/lotsCount', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `parking-lots/counts/${payload?.id ? payload?.id : store.getState().user?.adminData?.admin?._id}?page=${payload?.pagenumber}&limit=${payload?.limit}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from lot count ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const createMultipleUser = createAsyncThunk('user/multiple', async (payload) => {
    console.log("user csv ===>", payload)
    try {
        const response = await axios.post(apiUtility.baseURL + 'users/create-multiple', payload?.data, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 201) {
            store.dispatch(getAllUsers({ token: payload?.token, params: { page: 1, limit: 100000, isAvailable: true, search: '', sortBy: 'created' } }))
            return
        }
    } catch (err) {
        console.log('Reducer : error from createMultipleUser ====', err)
        if (err?.response?.status == 500) {
            payload?.alert(payload?.alertMsg)
        }
        if (err?.response?.status == 404) {
            payload?.alert(err?.response?.data?.message)
        }
        if (err?.response?.status == 403) {
            payload?.alert(err?.response?.data?.message)
        }
        if (err?.response?.status == 401) {
            Router.push('/')
        }
        return

    }
})

const createAnnouncement = createAsyncThunk('user/accouncement', async (payload) => {
    try {
        const response = await axios.post(apiUtility.baseURL + 'announcements', payload?.data, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 201) {
            store.dispatch(getAllAnnouncement())
            payload?.successModel && payload?.successModel()
            payload?.clearStates && payload?.clearStates()
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from create announcement ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const createUser = createAsyncThunk('user/createUser', async (payload) => {
    try {
        const dataObj = {
            ...payload?.data,
            middleName: '',
            lastName: '',
            generateRandom: true,
            electricCharging: payload?.data?.electricCharging == 'Yes' ? true : false,
            parkingLots: payload?.allowedLots ? payload?.allowedLots?.map(item => item.parkinglot) : [],
            designatedParkingSpot: payload?.allowedLots ? payload?.allowedLots?.map(item => item?.designatedParkingSpot)?.filter(item => item?._id != '1') : [],
            disabled: payload?.data?.accessibleParkingSpot == 'Yes' ? true : false,
            mainParkingLot: payload?.mainParkingLot,
            vehicles: payload?.vehicles
        }
        const response = await axios.post(apiUtility.baseURL + 'users', dataObj, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        // console.log('resposne =====', response?.data)
        if (response.status == 201) {
            store.dispatch(getAllUsers({
                token: payload?.token, params: {
                    page: 1,
                    limit: 100000,
                    isAvailable: true,
                    search: '',
                    sortBy: 'created'
                }
            }))
            payload?.setCreateUser()
            payload?.setUserDetail()
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from create user ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
        if (err?.response?.status == 400) {
            payload?.alert(err?.response?.data?.message)
        }
    }
})

const createGuestUser = createAsyncThunk('user/createGuestUser', async (payload) => {
    try {
        const dataObj = {
            ...payload?.data,
            electricCharging: payload?.data?.electricCharging,
            parkingLots: payload?.allowedLots ? payload?.allowedLots?.map(item => item.parkinglot) : [],
            designatedParkingSpot: payload?.allowedLots ? payload?.allowedLots?.map(item => item?.designatedParkingSpot)?.filter(item => item?._id != '1') : [],
            disabled: payload?.data?.accessibleParkingSpot,
            mainParkingLot: payload?.mainParkingLot,
            vehicles: payload?.vehicles,
            reservationDate: payload?.reservationDate
        }
        const response = await axios.post(apiUtility.baseURL + 'users/guest', dataObj, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 201) {
            payload?.setCreateUser()
            payload?.selectedParkingLot && store.dispatch(getAllGuestUsers({
                params: {
                    page: 1, limit: 5000000, sort: 'asc', sortBy: 'created', parkingLot: payload?.selectedParkingLot, noLoader: false
                }
            }))
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from createGuestUser ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
        if (err?.response?.status == 400) {
            payload?.alert(err?.response?.data?.message)
        }
    }
})

const guestUserSearch = createAsyncThunk('user/guestusersearch', async (paylaod) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `users/guest/search/${paylaod?.searchGuestUser}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            paylaod?.focus && paylaod?.focus()
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from guestUserSearch ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const updateUser = createAsyncThunk('user/updateUser', async (payload) => {
    try {
        const dataObj = {
            ...payload?.data,
            firstName: payload?.data?.name ? payload?.data?.name : '',
            middleName: '',
            lastName: '',
            electricCharging: payload?.data?.electricCharging == 'Yes' ? true : false,
            parkingLots: payload?.allowedLots ? payload?.allowedLots?.map(item => item.parkinglot) : undefined,
            designatedParkingSpot: payload?.allowedLots ? payload?.allowedLots?.map(item => item.designatedParkingSpot).filter(item => item?._id != '1') : undefined,
            disabled: payload?.data?.accessibleParkingSpot == 'Yes' ? true : false,
            mainParkingLot: payload?.mainParkingLot,
            vehicles: payload?.vehicles
        }
        // console.log('paylaod update ====', dataObj)
        const response = await axios.put(apiUtility.baseURL + `users/${payload?.userId}`, dataObj, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            Router.back()
            store.dispatch(getAllUsers({
                token: payload?.token, params: {
                    page: 1,
                    limit: 100000,
                    isAvailable: true,
                    search: '',
                    sortBy: 'created'
                }
            }))
            // payload?.setAdminDetail()
            return
        }
    } catch (err) {
        console.log('Reducer : error from update user ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
        if (err?.response?.status == 400) {
            payload?.alert(err?.response?.data?.message)
        }
    }
})

const updateGuestUser = createAsyncThunk('user/updateguestuser', async (payload) => {
    const disableGuestEdit = payload?.disableGuestEdit ?? true
    try {
        const dataObj = {
            ...(disableGuestEdit ? {} : payload),
            parkingLots: payload?.allowedLots ? payload?.allowedLots?.map(item => item.parkinglot) : undefined,
            designatedParkingSpot: payload?.allowedLots ? payload?.allowedLots?.map(item => item.designatedParkingSpot).filter(item => item?._id != '1') : undefined,
        }
        const response = await axios.put(apiUtility.baseURL + `users/guest/${payload?.userId}`, dataObj, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        console.log('response update ===--==', response?.data);
        if (response.status == 200) {
            store.dispatch(setGuestUserNameSuccess(response?.data?.user?.parkingLots?.filter((item, index) => (index > payload?.checkParkingLots?.length - 1))))
            const pathname =disableGuestEdit ? "/users" :'/dashboard'
            Router.push(pathname)
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from updateGuestUser ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
        if (err?.response?.status == 400) {
            payload?.alert(err?.response?.data?.message)
        }
    }
})

const deleteUser = createAsyncThunk('user/deleteUser', async (payload) => {
    try {
        const response = await axios.delete(apiUtility.baseURL + `users/${payload?.id}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
          store.dispatch(
            getAllUsers({
              token: payload?.token,
              params: {
                page: 1,
                limit: 100000,
                isAvailable: true,
                search: "",
                sortBy: "created",
              },
            })
          );
          !payload?.notBack && Router.back();
          return;
        }
    } catch (err) {
        console.log('Reducer : error from delete user ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})

const createTemporaryPassword = createAsyncThunk('user/userTemporaryPass', async (payload) => {
    try {
        const dataObj = {
            ...payload?.data,
            isDev: false
        }
        const response = await axios.post(apiUtility.baseURL + 'users/forgot-password', dataObj, {
            headers: {
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 201) {
            payload?.alert(response?.data?.message)
            return
        }
    } catch (err) {
        console.log('Reducer : error from createTemporaryPassword ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})


const getParkingLotLevels = createAsyncThunk('user/levels', async (payload) => {
    try {
        // console.log('payload ===',payload)
        const response = await axios.get(apiUtility.baseURL + `levels/parking-lot/${payload?.parkingLotId}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            return response.data
        }
        // console.log('response from get parking lots ===',response)
    } catch (err) {
        console.log('Reducer : error from getParkingLotLevels ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})



const uploadImage2 = createAsyncThunk('user/uploadImage2', async (payload) => {
    try {
        const dataObj = payload?.data
        const imgFormData = new FormData();
        imgFormData.append('images', payload?.data?.map)
        const response = await axios.post(apiUtility.baseURL + 'upload-images', imgFormData, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'multipart/form-data',
            }
        })
        if (response.status == 201) {
            dataObj.map = response.data[0]
            if (payload?.setEditableSpot) {
                store.dispatch(updateLevel({ token: payload?.token, data: dataObj, setEditableSpot: payload?.setEditableSpot, levelId: payload?.levelId }))
            } else {
                store.dispatch(createLevels({ token: payload?.token, data: dataObj, setNewRow: payload?.setNewRow }))
            }
            return
        }
    } catch (err) {
        console.log('Reducer : error from upload images ====', err)
        store.dispatch(setLoader(false))
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const uploadVideo = createAsyncThunk('user/uploadvideo', async (payload) => {
    try {
        const dataObj = payload?.data
        const videoData = new FormData();
        videoData.append('videos', payload?.data?.map)
        const response = await axios.post(apiUtility.baseURL + 'upload-videos', videoData, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'multipart/form-data',
            }
        })
        if (response.status == 201) {
            dataObj.map = response.data[0]
            if (payload?.setEditableSpot) {
                console.log('updating level api call')
                store.dispatch(updateLevel({ token: payload?.token, data: dataObj, setEditableSpot: payload?.setEditableSpot, levelId: payload?.levelId }))
            } else {
                console.log('creating level api call')
                store.dispatch(createLevels({ token: payload?.token, data: dataObj, setNewRow: payload?.setNewRow }))
            }
            return
        }
    } catch (err) {
        console.log('Reducer : error from upload video ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const createLevels = createAsyncThunk('user/levelCreate', async (payload) => {
    try {
        const dataObj = {
            ...payload?.data,
            parkingLot: payload?.data?.parkingLotId,
            level: Number(payload?.data?.level),
            map: payload?.data?.map,
            entrance: payload?.data?.entrance,
            regularParkingSpots: payload?.data?.regular,
            designatedParkingSpots: payload?.data?.designated,
            electricParkingSpots: payload?.data?.electric,
            language: i18n.language == 'en' ? 'en' : 'heb'

        }
        const response = await axios.post(apiUtility.baseURL + 'levels', dataObj, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response?.status == 201) {
            store.dispatch(getParkingLots({ token: payload?.token, currentAdmin: store.getState().user?.adminData?.admin?._id }));
            Router.back()
            payload?.setNewRow()
            return response
        }
    } catch (err) {
        console.log('Reducer : error from createLevels ====', err)
        if (err?.response?.status == 400) {
            alert(err?.response?.data?.message)
        }
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const deleteLevel = createAsyncThunk('user/deleteLevel', async (payload) => {
    try {
        const response = await axios.delete(apiUtility.baseURL + `levels/${payload?.id}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            store.dispatch(getParkingLots({ token: payload?.token }))
            Router.back()
            return
        }
    } catch (err) {
        console.log('Reducer : error from deleteLevel ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})

const updateLevel = createAsyncThunk('user/updateLevel', async (payload) => {
    try {
        const dataObj = {
            ...payload?.data,
            parkingLot: payload?.data?.parkingLotId,
            level: payload?.data?.level,
            map: payload?.data?.map,
            entrance: payload?.data?.entrance,
            regularParkingSpots: payload?.data?.regular,
            designatedParkingSpots: payload?.data?.designated,
            electricParkingSpots: payload?.data?.electric,
            language: i18n.language == 'en' ? 'en' : 'heb'
        }
        const response = await axios.patch(apiUtility.baseURL + `levels/${payload?.levelId}`, dataObj, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        // console.log('response ====', response)
        if (response.status == 200) {
            store.dispatch(getParkingLots({ token: payload?.token, currentAdmin: store.getState().user?.adminData?.admin?._id }))
            Router.back()
            payload?.setEditableSpot()
            return
        }
    } catch (err) {
        console.log('Reducer : error from updateLevel ====', err)
        if (err?.response?.status == 400) {
            alert(err?.response?.data?.message)
        }
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const deleteParking = createAsyncThunk('user/deleteparking', async (payload) => {
    try {
        const response = await axios.delete(apiUtility.baseURL + `parking-lots/${payload?.id}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })

        if (response?.status == 200) {
            store.dispatch(getParkingLots({ token: payload?.token, currentAdmin: store.getState().user?.adminData?.admin?._id }))
            Router.back()
            return
        }
    } catch (err) {
        console.log('Reducer : error from deleteParking ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const getAllUsers = createAsyncThunk('user/allUsers', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `${(store?.getState()?.user?.adminData?.admin?.role == 'admin' || payload?.fromSearch) ? 'users' : `users/admin-users/${store?.getState()?.user?.adminData?.admin?._id}`}?page=${payload?.params?.page}&limit=${50}&isAvailable=${payload?.params?.isAvailable}&isGuest=${payload?.params?.isGuest ?? 'all'}&search=${payload?.params?.search}&sort=${payload?.params?.sort}&sortBy=${payload?.params?.sortBy}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        // console.log('response =====', response?.data)
        if (response.status == 200) {
            payload?.focus && payload?.focus()
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from all users ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const getAllAssociatedUsers = createAsyncThunk('user/allAssociatedUsers', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `${(store?.getState()?.user?.adminData?.admin?.role == 'admin' || payload?.fromSearch) ? 'users' : `users/admin-users/${store?.getState()?.user?.adminData?.admin?._id}`}?page=${payload?.params?.page}&limit=${50}&isAvailable=${payload?.params?.isAvailable}&isGuest=${payload?.params?.isGuest}&search=${payload?.params?.search}&sort=${payload?.params?.sort}&sortBy=${payload?.params?.sortBy}`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        // console.log('response =====', response?.data)
        if (response.status == 200) {
            payload?.focus && payload?.focus()
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from all users ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const getAllGuestUsers = createAsyncThunk('user/getAllGuestUsers', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `users/guest?page=${payload?.params?.page}&limit=${payload?.params?.limit || 5000000}&sort=${payload?.params?.sort}&sortBy=${payload?.params?.sortBy}&parkingLot=${payload?.params?.parkingLot}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        // console.log('response =====', response?.data)
        if (response.status == 200) {
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from getAllGuestUsers ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const getSingleUser = createAsyncThunk('users/user', async (paylaod) => {
    try {
        const resposne = await axios.get(apiUtility.baseURL + `users/user/${paylaod?.id}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (resposne.status == 200) {
            return resposne?.data
        }
    } catch (err) {
        console.log('Reducer : error from getSingleUser ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }

})

const getParkingSpots = createAsyncThunk('user/parkingSpots', async (payload) => {
    try {
        // console.log(payload)
        const response = await axios.get(apiUtility.baseURL + `parking-spots/lot/${payload?.parkingLotId}?isAvailable=${payload?.isAvailable}&type=${payload?.type}&page=1&limit=250`, {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            if (payload?.fromCreate_UpdateUser) {
                const updatedParkingSpots = [...payload?.allowedLots];
                updatedParkingSpots[payload?.index]['designatedParkingSpot'] = '';
                updatedParkingSpots[payload?.index]['designatedParkingSpotOptions'] = payload?.parkinglots ? (payload?.parkinglots[payload?.index]?._id == payload?.parkingLotId ? ([...response?.data?.parkingSpots, payload?.designatedParkingSpot[payload?.index]].sort((a, b) => (a.parkingCode > b.parkingCode) ? 1 : -1)) : response?.data?.parkingSpots) : response?.data?.parkingSpots;
                payload?.setAllowedLots(updatedParkingSpots);
            }
            return response?.data
        }
    } catch (err) {
        console.log('Reducer : error from get all parking spots ====', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const getSmsSendTime = createAsyncThunk('user/smsSendTime', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + 'message-times', {
            headers: {
                'Authorization': `Bearer ${payload?.token}`,
                'Content-Type': 'application/json',
            }
        })
        // console.log('response ====',response)
        if (response.status == 200) {
            return response?.data
        }
    } catch (err) {
        console.log('reducer ==== error from get smsSendTime', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})

const unlockUser = createAsyncThunk('user/unlockUser', async (payload) => {
    try {
        const { id, token } = payload
        const response = await axios.patch(apiUtility.baseURL + `users/unlock-account/${id}`, {}, {
            headers: {
                'Authorization': `Bearer ${token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response?.status == 200) {
            alert(response?.data?.message)
            return
        }
    } catch (err) {
        console.log('reducer : error from unlock user ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const getAllAnnouncement = createAsyncThunk('user/announcements', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `announcements/admin/${store.getState().user?.adminData?.admin?._id}?page=1&limit=100&currentDate=${getCorrectDateTime(new Date())}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        // console.log('response ===', response)
        if (response.status == 200) {
            return response?.data
        }
    } catch (err) {
        console.log('reducer : error from getAllAnnouncement ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const deleteSingleAnnouncement = createAsyncThunk('user/deleteAnnouncement', async (payload) => {
    try {
        const response = await axios.delete(apiUtility.baseURL + `announcements/${payload?.id}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            store.dispatch(getAllAnnouncement())
            return response?.data
        }
    } catch (err) {
        console.log('reducer : error from deleteAnnouncement ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }

    }
})

const getAllMonitoringLots = createAsyncThunk('user/allMonitorslots', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `parking-spots/lot-monitor/${payload?.id}?page=${payload?.params?.page}&limit=${payload?.params?.limit || 1000000}&sort=${payload?.params?.sort}&sortBy=${payload?.params?.sortBy}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            return response?.data
        }
    } catch (err) {
        console.log('reducer : error from getAllMonitoringLots ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const getOccupancyLots = createAsyncThunk('user/allOccupancyLots', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `parking-spots/lot-occupancy/${payload?.id}?page=${payload?.params?.page}&limit=${payload?.params?.limit || 1000000}&sort=${payload?.params?.sort}&sortBy=${payload?.params?.sortBy}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            return response?.data
        }
    } catch (err) {
        console.log('reducer : error from getAllMonitoringLots ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const getAllHolidays = createAsyncThunk('user/allHolidays', async (payload) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `holidays`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            return response?.data
        }
    } catch (err) {
        console.log('reducer : error from getAllHolidays ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const createHoliday = createAsyncThunk('user/createHoliday', async (paylaod) => {
    try {
        const response = await axios.post(apiUtility.baseURL + `holidays`, paylaod?.data, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 201) {
            store.dispatch(getAllHolidays())
            paylaod?.setCreateHoliday && paylaod?.setCreateHoliday()
            return
        }
    } catch (err) {
        console.log('reducer : error from createHoliday ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const updateHoliday = createAsyncThunk('user/updateHoliday', async (paylaod) => {
    try {
        const response = await axios.put(apiUtility.baseURL + `holidays/${paylaod?.id}`, paylaod?.data, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status == 200) {
            store.dispatch(getAllHolidays())
            paylaod?.goBack && paylaod?.goBack()
            return
        }
    } catch (err) {
        console.log('reducer : error from updateHoliday ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const deleteHoliday = createAsyncThunk('user/holidayDelete', async (paylaod) => {
    try {
        const resposne = await axios.delete(apiUtility.baseURL + `holidays/${paylaod?._id}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (resposne.status == 200) {
            store.dispatch(getAllHolidays())
            return
        }
    } catch (err) {
        console.log('reducer : error from deleteHoliday ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const exportUsersList = createAsyncThunk('user/exportuserslist', async (paylaod) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `${store.getState()?.user?.adminData?.admin?.role == 'admin' ? 'users/report' : `users/report?currentAdmin=${store.getState()?.user?.adminData?.admin?._id}`}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status === 200) {
            window.open(response?.data?.path, '_self')
            return
        }
    } catch (err) {
        console.log('reducer : error from exportUsersList ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const exportReportsList = createAsyncThunk('user/exportreportslist', async (paylaod) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `complaints/report`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status === 200) {
            window.open(response?.data?.path, '_self')
            return
        }
    } catch (err) {
        console.log('reducer : error from exportReportsList ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const exportGuestUsers = createAsyncThunk('user/exportGuestlist', async (paylaod) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `users/report/guest`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        console.log(response.data);
        if (response.status === 200) {
            window.open(response?.data?.path, '_self')
            return
        }
    } catch (err) {
        console.log('reducer : error from exportReportsList ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})

const exportmonitoringList = createAsyncThunk('user/exportmonitoringlist', async (paylaod) => {
    try {
        const response = await axios.get(apiUtility.baseURL + `parking-lots/report/${paylaod?.id}`, {
            headers: {
                'Authorization': `Bearer ${store?.getState()?.user?.adminData?.token}`,
                'Content-Type': 'application/json',
            }
        })
        if (response.status === 200) {
            window.open(response?.data?.path, '_self')
            return
        }
    } catch (err) {
        console.log('reducer : error from exportmonitoringList ===', err)
        if (err?.response?.status == 401) {
            Router.push('/')
        }
    }
})



export {
    loginAdmin, forgetPassword, newPassword, getAllAdmins, deleteAdmin, getFaultReport, getParkingLotLevels, getAllUsers, getAllGuestUsers, getSingleUser, createAdmin, deleteFaultReport, updateParkingLot, getParkingLots, createAnnouncement, uploadImage, uploadFile, lotCount, editParkingLot, deleteUser, createUser, createGuestUser, guestUserSearch, createTemporaryPassword, updateUser, updateGuestUser, createLevels, uploadImage2, updateLevel, deleteLevel, uploadVideo, deleteParking, createMultipleUser, getParkingSpots, getSmsSendTime, unlockUser, getAllAnnouncement, deleteSingleAnnouncement, getAllMonitoringLots, getOccupancyLots, getAllHolidays, createHoliday, updateHoliday, deleteHoliday, exportUsersList, exportReportsList, exportmonitoringList, exportGuestUsers, addArchieve, getAssociateParkingLots,getAllAssociatedUsers
}