import { createSlice } from '@reduxjs/toolkit';
import produce from 'immer';
import { deleteAdmin, forgetPassword, getAllAdmins, getFaultReport, loginAdmin, newPassword, getAllUsers, createAdmin, deleteFaultReport, getParkingLots, createAnnouncement, lotCount, uploadImage, uploadFile, editParkingLot, createUser, createTemporaryPassword, updateUser, deleteUser, getParkingLotLevels, deleteLevel, uploadImage2, createLevels, updateLevel, updateParkingLot, createMultipleUser, deleteParking, uploadVideo, getParkingSpots, getSmsSendTime, unlockUser, getAllAnnouncement, deleteSingleAnnouncement, getAllMonitoringLots, getSingleUser, getAllHolidays, deleteHoliday, createHoliday, updateHoliday, exportUsersList, exportReportsList, exportmonitoringList, addArchieve, getOccupancyLots, createGuestUser, getAllGuestUsers, guestUserSearch, exportGuestUsers, updateGuestUser, getAssociateParkingLots, getAllAssociatedUsers, } from './userReducer';

export const userSlice = createSlice({
  name: 'user',
  initialState: {
    adminData: {},
    error: {},
    loader: false,
    login: false,
    forgetmsg: {},
    newPass: {},
    allAdmins: [],
    faultReports: [],
    allUsers: [],
    allGuestUsers: [],
    guestSearchUsers: null,
    singleUser: {},
    parkingLots: null,
    lotsCount: null,
    parkingLevels: {},
    parkingSpots: {},
    smsSendTime: [],
    allAnnouncements: [],
    monitoringLevelsSpots: [],
    occupancyLevelsSpots: [],
    allHolidays: [],
    monitoringState: {
      selectedlot: null,
    },
    from: null,
    parkinglotnameoccupancy: null,
    guestUserNameSuccess: null,
    occupancyDropdownSelectedParkingLot: null,
    associateParkingLots: null,
    associatedUsers:[]
  },
  reducers: {
    setAdminData: (state, action) => {
      state.adminData = action.payload;
    },
    setError: (state, action) => {
      state.error = action.payload
    },
    setLogin: (state, action) => {
      state.login = action.payload
    },
    setForget: (state, action) => {
      state.forgetmsg = action.payload
    },
    setNewPass: (state, action) => {
      state.newPass = action?.payload
    },
    setClearData: (state, action) => {
      state.adminData = {}
      state.error = {}
      state.login = false
      state.monitoringState.selectedlot = null
    },
    setLoader: (state, action) => {
      state.loader = action.payload
    },
    setMonitoringState: (state, action) => {
      state.monitoringState.selectedlot = action.payload
    },
    setFrom: (state, action) => {
      state.from = action.payload
    },
    setParkingLotNameOccupancy: (state, action) => {
      state.parkinglotnameoccupancy = action.payload
    },
    setGuestUserNameSuccess: (state, action) => {
      state.guestUserNameSuccess = action.payload
    },
    setGuestUserSearch: (state, action) => {
      state.guestSearchUsers = action.payload
    },
    setOccupancyDropdownSelectedParkingLot: (state, action) => {
      state.occupancyDropdownSelectedParkingLot = action?.payload
    }


  },

  extraReducers: (builder) => {
    builder
      .addCase(loginAdmin.pending, (state) => {
        state.loader = true
      })
      .addCase(loginAdmin.fulfilled, (state, action) => {
        state.loader = false
        if (action.payload) {
          state.adminData = action.payload;
          state.error = {}
        }
      })
      .addCase(loginAdmin.rejected, (state, action) => {
        state.loader = false
      });


    builder
      .addCase(forgetPassword.pending, (state) => {
        state.loader = true
      })
      .addCase(forgetPassword.fulfilled, (state, action) => {
        state.loader = false
        if (action.payload) {
          state.forgetmsg = action.payload;
          state.error = {}
        }
      })
      .addCase(forgetPassword.rejected, (state, action) => {
        state.loader = false
      });


    builder
      .addCase(newPassword.pending, (state) => {
        state.loader = true
      })
      .addCase(newPassword.fulfilled, (state, action) => {
        state.loader = false
        if (action.payload) {
          state.newPass = action.payload;
          state.error = {}
        }
      })
      .addCase(newPassword.rejected, (state, action) => {
        state.loader = false
      });

    builder
      .addCase(getAllAdmins.pending, (state) => {
        state.loader = true
      })
      .addCase(getAllAdmins.fulfilled, (state, action) => {
        state.loader = false
        if (action.payload) {
          state.allAdmins = action.payload;
        }
      })
      .addCase(getAllAdmins.rejected, (state, action) => {
        state.loader = false
      });


    builder
      .addCase(deleteAdmin.pending, (state) => {
        state.loader = true
      })
      .addCase(deleteAdmin.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(deleteAdmin.rejected, (state, action) => {
        state.loader = false
      });


    builder
      .addCase(getFaultReport.pending, (state) => {
        state.loader = true
      })
      .addCase(getFaultReport.fulfilled, (state, action) => {
        state.loader = false
        if (action.payload) {
          state.faultReports = action.payload
        }
      })
      .addCase(getFaultReport.rejected, (state, action) => {
        state.loader = false
      });


    builder
      .addCase(getAllUsers.pending, (state) => {
        state.loader = true
      })
      .addCase(getAllUsers.fulfilled, (state, action) => {
        if (action.payload) {
          state.allUsers = action.payload
        }
        state.loader = action?.meta?.arg?.noLoader ? true : false
      })
      .addCase(getAllUsers.rejected, (state, action) => {
        state.loader = action?.meta?.arg?.noLoader ? true : false
      });
      
    builder
      .addCase(getAllAssociatedUsers.pending, (state) => {
        state.loader = true
      })
      .addCase(getAllAssociatedUsers.fulfilled, (state, action) => {
        if (action.payload) {
          state.associatedUsers = action.payload
        }
        state.loader = action?.meta?.arg?.noLoader ? true : false
      })
      .addCase(getAllAssociatedUsers.rejected, (state, action) => {
        state.loader = action?.meta?.arg?.noLoader ? true : false
      });

    builder
      .addCase(getAllGuestUsers.pending, (state, action) => {
        if (action?.meta?.arg?.noLoader == false) {
          state.loader = true
        }
      })
      .addCase(getAllGuestUsers.fulfilled, (state, action) => {
        if (action.payload) {
          state.allGuestUsers = action.payload
        }
        if (action?.meta?.arg?.noLoader == false) {
          state.loader = false
        }
      })
      .addCase(getAllGuestUsers.rejected, (state, action) => {
        if (action?.meta?.arg?.noLoader == false) {
          state.loader = false
        }
      });

    builder
      .addCase(createAdmin.pending, (state, action) => {
        state.loader = true
      })
      .addCase(createAdmin.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(createAdmin.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(addArchieve.pending, (state, action) => {
        state.loader = true
      })
      .addCase(addArchieve.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(addArchieve.rejected, (state, action) => {
        state.loader = false
      })


    builder
      .addCase(getParkingLots.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getParkingLots.fulfilled, (state, action) => {
        state.loader = action?.meta?.arg?.noLoader ? true : false
        if (action.payload) {
          state.parkingLots = action.payload
        }
      })
      .addCase(getParkingLots.rejected, (state, action) => {
        state.loader = action?.meta?.arg?.noLoader ? true : false
      })

    builder
      .addCase(getAssociateParkingLots.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getAssociateParkingLots.fulfilled, (state, action) => {
        state.loader = action?.meta?.arg?.noLoader ? true : false
        if (action.payload) {
          state.associateParkingLots = action.payload
        }
      })
      .addCase(getAssociateParkingLots.rejected, (state, action) => {
        state.loader = action?.meta?.arg?.noLoader ? true : false
      })


    builder
      .addCase(createAnnouncement.pending, (state, action) => {
        state.loader = true
      })
      .addCase(createAnnouncement.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(createAnnouncement.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(lotCount.pending, (state, action) => {
        state.loader = true
      })
      .addCase(lotCount.fulfilled, (state, action) => {
        state.loader = action?.meta?.arg?.noLoader ? true : false
        if (action.payload) (
          state.lotsCount = action.payload
        )
      })
      .addCase(lotCount.rejected, (state, action) => {
        state.loader = action?.meta?.arg?.noLoader ? true : false
      })

    builder
      .addCase(uploadImage.pending, (state, action) => {
        state.loader = true
      })
      .addCase(uploadImage.fulfilled, (state, action) => {
        // state.loader = false
      })
      .addCase(uploadImage.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(uploadFile.pending, (state, action) => {
        state.loader = true
      })
      .addCase(uploadFile.fulfilled, (state, action) => {
        // state.loader = false
      })
      .addCase(uploadFile.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(editParkingLot.pending, (state, action) => {
        state.loader = true
      })
      .addCase(editParkingLot.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(editParkingLot.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(createUser.pending, (state, action) => {
        state.loader = true
      })
      .addCase(createUser.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(createUser.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(createGuestUser.pending, (state, action) => {
        state.loader = true
      })
      .addCase(createGuestUser.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(createGuestUser.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(guestUserSearch.pending, (state, action) => {
        state.loader = action?.meta?.arg?.noLoader ? false : true
      })
      .addCase(guestUserSearch.fulfilled, (state, action) => {
        state.guestSearchUsers = action.payload
        state.loader = false
      })
      .addCase(guestUserSearch.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(createTemporaryPassword.pending, (state, action) => {
        state.loader = true
      })
      .addCase(createTemporaryPassword.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(createTemporaryPassword.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(updateUser.pending, (state, action) => {
        state.loader = true
      })
      .addCase(updateUser.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(updateUser.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(updateGuestUser.pending, (state, action) => {
        state.loader = true
      })
      .addCase(updateGuestUser.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(updateGuestUser.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(deleteUser.pending, (state, action) => {
        state.loader = true
      })
      .addCase(deleteUser.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(deleteUser.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(getParkingLotLevels.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getParkingLotLevels.fulfilled, (state, action) => {
        state.loader = false
        if (action.payload) {
          state.parkingLevels = action.payload
        }
      })
      .addCase(getParkingLotLevels.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(deleteLevel.pending, (state, action) => {
        state.loader = true
      })
      .addCase(deleteLevel.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(deleteLevel.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(uploadImage2.pending, (state, action) => {
        state.loader = true
      })
      .addCase(uploadImage2.fulfilled, (state, action) => {
        // state.loader = false
      })
      .addCase(uploadImage2.rejected, (state, action) => {
        state.loader = false
      })


    builder
      .addCase(createLevels.pending, (state, action) => {
        state.loader = true
      })
      .addCase(createLevels.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(createLevels.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(updateLevel.pending, (state, action) => {
        state.loader = true
      })
      .addCase(updateLevel.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(updateLevel.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(updateParkingLot.pending, (state, action) => {
        state.loader = true
      })
      .addCase(updateParkingLot.fulfilled, (state, action) => {
        // state.loader = false
      })
      .addCase(updateParkingLot.rejected, (state, action) => {
        state.loader = false
      })


    builder
      .addCase(createMultipleUser.pending, (state, action) => {
        state.loader = true
      })
      .addCase(createMultipleUser.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(createMultipleUser.rejected, (state, action) => {
        state.loader = false
      })


    builder
      .addCase(deleteParking.pending, (state, action) => {
        state.loader = true
      })
      .addCase(deleteParking.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(deleteParking.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(uploadVideo.pending, (state, action) => {
        state.loader = true
      })
      .addCase(uploadVideo.fulfilled, (state, action) => {
        // state.loader = false
      })
      .addCase(uploadVideo.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(getParkingSpots.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getParkingSpots.fulfilled, (state, action) => {
        if (action?.payload) {
          state.parkingSpots = action.payload
        }
        state.loader = false
      })
      .addCase(getParkingSpots.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(getSmsSendTime.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getSmsSendTime.fulfilled, (state, action) => {
        if (action?.payload) {
          state.smsSendTime = action.payload
        }
        state.loader = false
      })
      .addCase(getSmsSendTime.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(unlockUser.pending, (state, action) => {
        state.loader = true
      })
      .addCase(unlockUser.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(unlockUser.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(getAllAnnouncement.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getAllAnnouncement.fulfilled, (state, action) => {
        state.loader = false
        state.allAnnouncements = action?.payload
      })
      .addCase(getAllAnnouncement.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(deleteSingleAnnouncement.pending, (state, action) => {
        state.loader = true
      })
      .addCase(deleteSingleAnnouncement.fulfilled, (state, action) => {
        // state.loader = false
      })
      .addCase(deleteSingleAnnouncement.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(getAllMonitoringLots.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getAllMonitoringLots.fulfilled, (state, action) => {
        state.monitoringLevelsSpots = action?.payload
        state.loader = false
      })
      .addCase(getAllMonitoringLots.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(getOccupancyLots.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getOccupancyLots.fulfilled, (state, action) => {
        state.occupancyLevelsSpots = action?.payload
        state.loader = false
      })
      .addCase(getOccupancyLots.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(getSingleUser.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getSingleUser.fulfilled, (state, action) => {
        state.singleUser = action?.payload
        state.loader = false
      })
      .addCase(getSingleUser.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(getAllHolidays.pending, (state, action) => {
        state.loader = true
      })
      .addCase(getAllHolidays.fulfilled, (state, action) => {
        state.allHolidays = action?.payload
        state.loader = false
      })
      .addCase(getAllHolidays.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(deleteHoliday.pending, (state, action) => {
        state.loader = true
      })
      .addCase(deleteHoliday.fulfilled, (state, action) => {
        // state.loader = false
      })
      .addCase(deleteHoliday.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(createHoliday.pending, (state, action) => {
        state.loader = true
      })
      .addCase(createHoliday.fulfilled, (state, action) => {
        // state.loader = false
      })
      .addCase(createHoliday.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(updateHoliday.pending, (state, action) => {
        state.loader = true
      })
      .addCase(updateHoliday.fulfilled, (state, action) => {
        // state.loader = false
      })
      .addCase(updateHoliday.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(exportUsersList.pending, (state, action) => {
        state.loader = true
      })
      .addCase(exportUsersList.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(exportUsersList.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(exportReportsList.pending, (state, action) => {
        state.loader = true
      })
      .addCase(exportReportsList.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(exportReportsList.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(exportmonitoringList.pending, (state, action) => {
        state.loader = true
      })
      .addCase(exportmonitoringList.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(exportmonitoringList.rejected, (state, action) => {
        state.loader = false
      })

    builder
      .addCase(exportGuestUsers.pending, (state, action) => {
        state.loader = true
      })
      .addCase(exportGuestUsers.fulfilled, (state, action) => {
        state.loader = false
      })
      .addCase(exportGuestUsers.rejected, (state, action) => {
        state.loader = false
      })


  },


});

export const { setNewPass, setForget, setLogin, setClearData, setAdminData, setError, updateParkingsSpots, addNewParkingsSpot, deleteParkingsSpot,
  setLoader, setMonitoringState, setFrom, setParkingLotNameOccupancy, setGuestUserNameSuccess, setGuestUserSearch, setOccupancyDropdownSelectedParkingLot } = userSlice.actions;

export default userSlice.reducer;
